/*****************************************************************************
 *
 *  File: BC790101.ddl
 *
 *  Copyright (C) APLISENS S.A. All Rights Reserved 
 *  Authors:        Jacek Szumigaj
 *  Device:         APT-2000ALW 		        
 *  Communication:  HART        
 *  Revision:   1                                         
 *  Date:       2014.09.08 		                        
 *****************************************************************************/
 
/*****************************************************************************
 * The manufacturer line
 ****************************************************************************/
 
MANUFACTURER APLISENS, DEVICE_TYPE _MPT3, DEVICE_REVISION 1, DD_REVISION 3

/*****************************************************************************
 * Include Files
 *****************************************************************************/

#include "macros.h"
#include "methods.h"

/*****************************************************************************
 * Common Tables
 ****************************************************************************/
IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    VARIABLE units_code;
    VARIABLE transfer_function_code;
    VARIABLE material_code;
    VARIABLE alarm_selection_code;
    VARIABLE write_protect_code;
    VARIABLE company_identification_code;
    VARIABLE burst_mode_control_code;
    VARIABLE physical_signaling_codes;
    VARIABLE flag_assignment;
    VARIABLE operating_mode_code;
    VARIABLE analog_output_numbers_code;
    VARIABLE extended_device_status_codes;
    VARIABLE lock_device_codes;
    VARIABLE write_device_variable_codes;
    VARIABLE device_variable_family_codes;
    VARIABLE device_variable_classification_codes;
    VARIABLE trim_point_codes;
    VARIABLE capture_mode_codes;
    VARIABLE physical_layer_type_codes;
    VARIABLE lock_device_status_codes;
    VARIABLE analog_channel_flags;
    VARIABLE process_data_status;
    VARIABLE limit_status;
    VARIABLE device_family_status;
    VARIABLE manufacturer_id;
    VARIABLE private_label_distributor;
    VARIABLE device_type;
    VARIABLE write_protect;
    VARIABLE physical_signaling_code;
    VARIABLE device_flags;
    VARIABLE analog_channel_saturated1;
    VARIABLE analog_channel_fixed1;
    VARIABLE analog_channel_saturated_codes;
    VARIABLE analog_channel_fixed_codes;

    REDEFINITIONS
    {
        /*
         * The entire variable must be redefined since Device Type is defined as a two-byte 
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE device_type
        {
            LABEL [device_type];
            HELP [manufacturers_device_type_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Device Type code and appropriate label
                { 0x79,  "APT-2000ALW" }
            }
        }

        /*
         * The entire variable must be redefined since Manufacturer ID is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE manufacturer_id
        {
            LABEL [manufacturer_id];
            HELP [manufacturer_id_code_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Manufacturer code and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }

        /*
         * The entire variable must be redefined since Private Label is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE private_label_distributor
        {
            LABEL [private_label_distributor];
            HELP [private_label_distributor_help];
            CLASS DEVICE;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your manufactures id and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }
    }

}

/*****************************************************************************
 * Universal Commmands
 *****************************************************************************/

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 5, DD_REVISION 2
{    
    EVERYTHING;

    REDEFINITIONS
    {
        VARIABLE polling_address 
        {
            REDEFINE LABEL [polling_address];
            REDEFINE HELP [polling_address_help];
            REDEFINE HANDLING WRITE;
            REDEFINE CLASS HART;
            REDEFINE TYPE UNSIGNED_INTEGER
            {
	            MAX_VALUE 15;
            }
            REDEFINE DEFAULT_VALUE  0;
        }

        VARIABLE comm_status
        {
            REDEFINE CLASS LOCAL;
        }
    }
}

 /*****************************************************************************
 *                  PV, when the primary variable
 ******************************************************************************/

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        DELETE VARIABLE loop_flags;

        COLLECTION OF VARIABLE analog_io
        {
            MEMBERS
            {
                DELETE ANALOG_CHANNEL_FLAGS;
            } 
        }

        COLLECTION OF VARIABLE scaling
        {
            MEMBERS
            {
                ADD RANGE_UNITS, deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
            } 
        } 
       
    }
}

/*****************************************************************************
 *                  Common Practice Commands
 *****************************************************************************/
IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 7, DD_REVISION 4
{
    COMMAND write_pv_damping_value;                 /* command 34 */
    COMMAND write_pv_range_values;                  /* command 35 */
    COMMAND set_pv_upper_range_value;               /* command 36 */
    COMMAND set_pv_lower_range_value;               /* command 37 */ 
    COMMAND reset_configuration_change_flag;        /* command 38 */
    COMMAND enter_exit_fixed_pv_current_mode;       /* command 40 */
    COMMAND perform_device_reset;                   /* command 42 */
    COMMAND set_pv_zero;                            /* command 43 */
    COMMAND write_pv_units;                         /* command 44 */
    COMMAND trim_pv_current_dac_zero;               /* command 45 */
    COMMAND trim_pv_current_dac_gain;               /* command 46 */
    COMMAND write_pv_transfer_function;             /* command 47 */
    COMMAND read_additional_device_status;          /* command 48 */
    COMMAND write_pv_sensor_serial_number;          /* command 49 */
    COMMAND write_number_of_response_preambles;     /* command 59 */
  
    METHOD applied_rerange;
    METHOD zero_trim;
    METHOD return_to_normal;
    METHOD warning_message;
    METHOD device_self_test;
    METHOD device_master_reset;
    METHOD transmitter_loop_test;
    METHOD transmitter_dac_trim;

    VARIABLE device_specific_status_0;
    VARIABLE device_specific_status_1;
    VARIABLE device_specific_status_2;
    VARIABLE device_specific_status_3;
    VARIABLE device_specific_status_4;
    VARIABLE device_specific_status_5;
    VARIABLE device_specific_status_14;
    VARIABLE device_specific_status_15;
    VARIABLE device_specific_status_16;
    VARIABLE device_specific_status_17;
    VARIABLE device_specific_status_18;
    VARIABLE device_specific_status_19;
    VARIABLE device_specific_status_20;
    VARIABLE device_specific_status_21;
    VARIABLE device_specific_status_22;
    VARIABLE device_specific_status_23;
    VARIABLE device_specific_status_24; 
    VARIABLE device_variable_code;

 /***********************************************************
                   REDEFINATIONS
 ************************************************************/                   

    REDEFINITIONS
    {

    COMMAND read_additional_device_status
    {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0 /*error_flags_2*/, device_specific_status_1 /*error_flags_1*/, 
                    device_specific_status_2, device_specific_status_3, 
                    device_specific_status_4, device_specific_status_5, 
                    0x00 /*extended_fld_device_status*/, 0x00 /*operatingMode*/, 
                    0x00 /*analog_channel_saturated3*/, 0x00 /*analog_channel_saturated2*/,  analog_channel_saturated1,
                    0x00 /*analog_channel_fixed3*/, 0x00 /*analog_channel_fixed2*/, analog_channel_fixed1, 
                    device_specific_status_14, device_specific_status_15, device_specific_status_16,
                    device_specific_status_17, device_specific_status_18, device_specific_status_19,
                    device_specific_status_20, device_specific_status_21, device_specific_status_22,
                    device_specific_status_23, device_specific_status_24 
                }
            }
        }
    }
}


/*****************************************************************
 * Dynamic Variables Configuration
 *****************************************************************/

VARIABLE temperatureValue
{
    LABEL "PV";
	HELP [sensor_temperature_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE temperatureUnits
{
    LABEL "Unit";
	HELP "Sensor Temperature Units- Engineering unit to be displayed with Sensor Temperature.";
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    { 
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
}

VARIABLE temperatureUSL
{
    LABEL "Upper Sensor Limit";
    HELP [upper_sensor_limit_help];
    CLASS CORRECTION; 
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f"; 
    }
}

VARIABLE temperatureLSL
{
    LABEL "Lower Sensor Limit";
    HELP [lower_sensor_limit_help];
    CLASS CORRECTION;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureMinimumSpan
{
    LABEL "Minimum Span";
    HELP [minimum_span_help];
    CLASS CORRECTION;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureDampingValue
{
    LABEL "Damping Value";
    HELP  [seconds_damping_value_help];
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
       DISPLAY_FORMAT  ".1f";
       EDIT_FORMAT     "8.1f";
    } 
} 

VARIABLE temperatureSerialNumber
{
    LABEL "Sensor serial number";
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";    
    } 
}
COLLECTION OF VARIABLE temperature
{
    LABEL [temperature];
    HELP "";
    MEMBERS
    {
        // Sensor Correction Information 
        DIGITAL_VALUE,              temperatureValue,           [sv],                   [digital_value_help];
        DIGITAL_UNITS,              temperatureUnits,           [units],                [digital_units_help];
        UPPER_SENSOR_LIMIT,         temperatureUSL,             [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         temperatureLSL,             [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               temperatureMinimumSpan,     [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              temperatureDampingValue,    [damping_value],        [seconds_damping_value_help];   
        SENSOR_SERIAL_NUMBER,       temperatureSerialNumber,    [sensor_serial_number], [sensor_serial_number_help];
        TRANSFER_FUNCTION,          transfer_function,          [transfer_function],    [transfer_function_help];
     }
}


VARIABLE chan1Value
{
    LABEL "chan1Value";
    HELP  "Channel 1 value";                           
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE chan1Unit
{
    LABEL "SV 1 unit";
	HELP "SV 1 Units- Engineering unit to be displayed with SV 1.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
} 

COLLECTION OF VARIABLE sv1
{
    LABEL "SV 1";
    HELP  "Channel 1 value";
    MEMBERS 
    {
        DIGITAL_VALUE,              chan1Value,                 "Value",                [digital_value_help];
        DIGITAL_UNITS,              chan1Unit,                  [units],                [digital_units_help];
    }
}

VARIABLE chan2Value
{
    LABEL "chan2Value";
    HELP  "Channel 2 value";                                   
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE chan2Unit
{
    LABEL "SV 2 unit";
	HELP "SV 2 Units- Engineering unit to be displayed with SV 2.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }                                                   
}  

COLLECTION OF VARIABLE sv2
{
    LABEL "SV 2";
    HELP  "Channel 2 value";
    MEMBERS 
    {
        DIGITAL_VALUE,              chan2Value,                 "Value",                [digital_value_help];
        DIGITAL_UNITS,              chan2Unit,                  [units],                [digital_units_help];
    }
}

VARIABLE cpuTemperatureValue
{
    LABEL "cpuTemperatureValue";
    HELP  [electronics_temperature_help];                               
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }     
}

VARIABLE cpuTempUnit
{
    LABEL "CPU Temp unit";
	HELP "CPU Temp Units- Engineering unit to be displayed with CPU Temp.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35)     // degress K 
    }
}

COLLECTION OF VARIABLE cpuTemperature
{
    LABEL "CPU Temp.";
    HELP  [electronics_temperature_help];
    MEMBERS 
    {
        DIGITAL_VALUE,              cpuTemperatureValue,         [temperature],          [digital_value_help];
        DIGITAL_UNITS,              cpuTempUnit,                 [units],                [digital_units_help];
    }
}
/******************* Device Variables *************************/

ARRAY OF COLLECTION deviceVariables 
{
    ELEMENTS
    {
        0, temperature, [pv];
        1, sv1, [sv];
        2, sv2, [tv];
        3, cpuTemperature, [qv];
    }
}

/***************************************************************************
                                MENU
 ***************************************************************************/

MENU root_menu
{
    STYLE WINDOW; 
    LABEL [bus_devices];
    ITEMS
    {   
        device_setup
    }
}




/**************************************************************
            MENU OUTPUT
***************************************************************/




/************************************************************
                MENU for device_setup
 **************************************************************/

MENU device_setup
{
    STYLE PAGE;
    LABEL [device_setup];
    ITEMS
    { 
        device_menu,
        device_menu_1,
        current_and_4_dynamic,
        device_info
    }
} 





MENU current_and_4_dynamic
{
    LABEL "Current and all dynamic variables";
    ITEMS 
    {  
     PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),                 // Current
     PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // PV
     SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // SV
     TV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // TV
     QV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE)               // QV 
    }
} 



MENU device_menu_1
{
    LABEL "Device Identification Part 2";
    ITEMS 
    {
      device_type (DISPLAY_VALUE),
      universal_revision (DISPLAY_VALUE),
      transmitter_revision (DISPLAY_VALUE),
      private_label_distributor (DISPLAY_VALUE)
    }
} 

MENU device_menu
{
    LABEL "Device Identification Part 1";
    ITEMS 
    {  
        manufacturer_id (DISPLAY_VALUE),
        device_id (DISPLAY_VALUE),
        software_revision (DISPLAY_VALUE),
        hardware_revision (DISPLAY_VALUE)

    }
}  

MENU device_info
{
    LABEL [device_information];
    ITEMS
    {
        tag(DISPLAY_VALUE),                         
        descriptor(DISPLAY_VALUE),                 
        message(DISPLAY_VALUE),
        date(DISPLAY_VALUE)  
    }
}

//---------------------- end of file ------------------------------------
      
