/*****************************************************************************
 *
 * File: APC-2000ALW.ddl
 *
 *  Copyright (C) APLISENS	. All Rights Reserved 
 *  Authors: Przemysaw Gromek, Waldemar Kupczyk, Konrad Jastrzb, Jacek Szumigaj
 *  Device:         APC-2000ALW, APR-2000ALW, APR-2200ALW 		        
 *  Communication:  HART        
 *  Revision:   1.2                                         
 *  Date:       2012.08.02 		                        
 *****************************************************************************
 * Copyright (c) 2012, Aplisens S.A., All Rights Reserved
 *****************************************************************************
 




/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */

MANUFACTURER APLISENS, DEVICE_TYPE _MPC5, DEVICE_REVISION 1, DD_REVISION 3

/*****************************************************************************
 * Include Files
 *****************************************************************************
 */

#include "macros.h"
#include "methods.h"

/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */
 
/*****************************************************************************
 * Common Tables
 *****************************************************************************/
IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    VARIABLE units_code;
    VARIABLE transfer_function_code;
    VARIABLE material_code;
    VARIABLE alarm_selection_code;
    VARIABLE write_protect_code;
    VARIABLE company_identification_code;
    VARIABLE burst_mode_control_code;
    VARIABLE physical_signaling_codes;
    VARIABLE flag_assignment;
    VARIABLE operating_mode_code;
    VARIABLE analog_output_numbers_code;
    VARIABLE extended_device_status_codes;
    VARIABLE lock_device_codes;
    VARIABLE write_device_variable_codes;
    VARIABLE device_variable_family_codes;
    VARIABLE device_variable_classification_codes;
    VARIABLE trim_point_codes;
    VARIABLE capture_mode_codes;
    VARIABLE physical_layer_type_codes;
    VARIABLE lock_device_status_codes;
    VARIABLE analog_channel_flags;
    VARIABLE process_data_status;
    VARIABLE limit_status;
    VARIABLE device_family_status;
    VARIABLE manufacturer_id;
    VARIABLE private_label_distributor;
    VARIABLE device_type;
    VARIABLE write_protect;
    VARIABLE physical_signaling_code;
    VARIABLE device_flags;
    VARIABLE analog_channel_saturated1;
    VARIABLE analog_channel_fixed1;
    VARIABLE analog_channel_saturated_codes;
    VARIABLE analog_channel_fixed_codes;

    REDEFINITIONS
    {
        /*
         * The entire variable must be redefined since Device Type is defined as a two-byte 
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE device_type
        {
            LABEL [device_type];
            HELP [manufacturers_device_type_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Device Type code and appropriate label
                { 0x7b,  "APC-2000 ALW" }
            }
        }

        /*
         * The entire variable must be redefined since Manufacturer ID is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE manufacturer_id
        {
            LABEL [manufacturer_id];
            HELP [manufacturer_id_code_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Manufacturer code and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }

        /*
         * The entire variable must be redefined since Private Label is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE private_label_distributor
        {
            LABEL [private_label_distributor];
            HELP [private_label_distributor_help];
            CLASS DEVICE;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your manufactures id and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }
    }

}

/*****************************************************************************
 * Universal Commmands
 *****************************************************************************/

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 5, DD_REVISION 2
{
    /* All HART devices must support all Universal Commands */

    EVERYTHING;

    REDEFINITIONS
    {
        VARIABLE polling_address 
        {
            REDEFINE LABEL [polling_address];
            REDEFINE HELP [polling_address_help];
            REDEFINE HANDLING WRITE;
            REDEFINE CLASS HART;
            REDEFINE TYPE UNSIGNED_INTEGER
            {
	            MAX_VALUE 15;
            }
            REDEFINE DEFAULT_VALUE  0;
        }

        VARIABLE comm_status
        {
            REDEFINE CLASS LOCAL;
        }
    }
}

/*****************************************************************************
 * PV, when the primary variable is not mappable we can import the PV
 * standard DD to take care of the dynamic variable array, loop current
 * and ranging functions
 *****************************************************************************/

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        DELETE VARIABLE loop_flags;

        COLLECTION OF VARIABLE analog_io
        {
            MEMBERS
            {
                DELETE ANALOG_CHANNEL_FLAGS;
            } 
        }

        /* 
         * Most devices use the same data item for range units (command 15) and the sensor units.
         * when this is true the following should be added.  if your device uses a different variable
         * for range units you should reference it here 
         */
        COLLECTION OF VARIABLE scaling
        {
            MEMBERS
            {
                ADD RANGE_UNITS, deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
            } 
        }
    }
}

/*****************************************************************************
 * Common Practice Commands
 */

IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 7, DD_REVISION 4 
{
    COMMAND write_pv_damping_value;                 /* command 34 */
    COMMAND write_pv_range_values;                  /* command 35 */
    COMMAND set_pv_upper_range_value;               /* command 36 */
    COMMAND set_pv_lower_range_value;               /* command 37 */ 
    COMMAND reset_configuration_change_flag;        /* command 38 */
    COMMAND enter_exit_fixed_pv_current_mode;       /* command 40 */
    COMMAND perform_device_reset;                   /* command 42 */
    COMMAND set_pv_zero;                            /* command 43 */
    COMMAND write_pv_units;                         /* command 44 */
    COMMAND trim_pv_current_dac_zero;               /* command 45 */
    COMMAND trim_pv_current_dac_gain;               /* command 46 */
    COMMAND write_pv_transfer_function;             /* command 47 */
    COMMAND read_additional_device_status;          /* command 48 */ 
    COMMAND write_pv_sensor_serial_number;          /* command 49 */
    COMMAND write_number_of_response_preambles;     /* command 59 */
    
    METHOD applied_rerange;
    METHOD zero_trim;
    METHOD return_to_normal;
    METHOD warning_message;
    METHOD device_self_test;
    METHOD device_master_reset;
    METHOD transmitter_loop_test;
    METHOD transmitter_dac_trim;

    VARIABLE device_specific_status_0;
    VARIABLE device_specific_status_1;
    VARIABLE device_specific_status_2;
    VARIABLE device_specific_status_3;
    VARIABLE device_specific_status_4;
    VARIABLE device_specific_status_5;
    VARIABLE device_specific_status_14;
    VARIABLE device_specific_status_15;
    VARIABLE device_specific_status_16;
    VARIABLE device_specific_status_17;
    VARIABLE device_specific_status_18;
    VARIABLE device_specific_status_19;
    VARIABLE device_specific_status_20;
    VARIABLE device_specific_status_21;
    VARIABLE device_specific_status_22;
    VARIABLE device_specific_status_23;
    VARIABLE device_specific_status_24;
    VARIABLE device_variable_code;
 
    REDEFINITIONS
    {
    VARIABLE device_specific_status_2 //wrd_SSMod_H
    {
        REDEFINE LABEL "Dev. Spec Status Byte 2"; //"wrd_SSMod_H";
        REDEFINE HELP "Device Specific Status Byte 2";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "Sensor Failure"},
    		{ 0x02, "Sensor Not Connected"},
    		{ 0x04, "Primary Variable Not Valid"},
    		{ 0x08, "Primary Variable Out Of Limits"},
    		{ 0x10, "Secondary Variable Out Of Limits"},
    		{ 0x20, "Analog Output Saturated"},
    		{ 0x40, "Output Current Fixed"},
    		{ 0x80, "Hot Start Occure"} 
        }                           
        REDEFINE POST_READ_ACTIONS
        {
             m_wrd_SSMod_H
        }
    }

    VARIABLE device_specific_status_3 //wrd_SSMod_L
    {
        REDEFINE LABEL "Dev. Spec Status Byte 3"; //"wrd_SSMod_L";
        REDEFINE HELP "Device Specific Status Byte 3";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "RAM Test Error"},
    		{ 0x02, "Flash CRC Error"},
    		{ 0x04, "Bad CRC In Segment INFO"},
    		{ 0x08, "Oscillator Fault"},
    		{ 0x10, "HT430 Init Error"},
    		{ 0x20, "ADC Interface Master Error"},
    		{ 0x40, "ADC Interface Slave Error"},
    		{ 0x80, "ADC Not Responded"}
        }
    }

    VARIABLE device_specific_status_14 // wrd_AI_Memory_Diagn
    {
        REDEFINE LABEL "AI Memory Diagnostics"; //"AI Memory Diagnostic";
        REDEFINE HELP "AI Memory Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "INFO Fault"},
    		{ 0x02, "INFO Recovery"},
    		{ 0x04, "INFO Recovery Fault"},
    		{ 0x08, "Backup Info Fault"},
    		{ 0x10, "Backup Info Recovery"},
    		{ 0x20, "Backup Info Recovery Fault"},
    		{ 0x40, "Flash Consistency Fault"}//,
    		//{ 0x80, "ADC_NOT_RESPONDED"}
        }
    }

    VARIABLE device_specific_status_15 //wrd_PB_Memory_Diagn
    {
        REDEFINE LABEL "PB Memory Diagnostics"; //"PB Memory Diagnostic";
        REDEFINE HELP "PB Memory Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "INFO Fault"},
    		{ 0x02, "INFO Recovery"},
    		{ 0x04, "INFO Recovery Fault"},
    		{ 0x08, "Backup Info Fault"},
    		{ 0x10, "Backup Info Recovery"},
    		{ 0x20, "Backup Info Recovery Fault"},
    		{ 0x40, "Flash Consistency Fault"}//,
    		//{ 0x80, "ADC_NOT_RESPONDED"}
        }
    }

    VARIABLE device_specific_status_16 //wrd_SB_Memory_Diagn
    {
        REDEFINE LABEL "SB Memory Diagnostics"; //"SB Memory Diagnostic";
        REDEFINE HELP "SB Memory Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "INFO Fault"},
    		{ 0x02, "INFO Recovery"},
    		{ 0x04, "INFO Recovery Fault"},
    		{ 0x08, "Backup Info Fault"},
    		{ 0x10, "Backup Info Recovery"},
    		{ 0x20, "Backup Info Recovery Fault"},
    		{ 0x40, "Flash Consistency Fault"}//,
    		//{ 0x80, "ADC_NOT_RESPONDED"}
        }
    }

    VARIABLE device_specific_status_17 //wrd_TB_Memory_Diagn
    {
        REDEFINE LABEL "TB Memory Diagnostics"; //"TB Memory Diagnostic";
        REDEFINE HELP "TB Memory Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "INFO Fault"},
    		{ 0x02, "INFO Recovery"},
    		{ 0x04, "INFO Recovery Fault"},
    		{ 0x08, "Backup Info Fault"},
    		{ 0x10, "Backup Info Recovery"},
    		{ 0x20, "Backup Info Recovery Fault"},
    		{ 0x40, "Flash Consistency Fault"}//,
    		//{ 0x80, "ADC_NOT_RESPONDED"}
        }
    }
    
    VARIABLE device_specific_status_19 //wrd_PB_Diagn
    {
        REDEFINE LABEL "PB Diagnostics"; 
        REDEFINE HELP "PB Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "PB LFXT1 Fault"},
    		{ 0x02, "PB Hart Fault"},
    		{ 0x04, "PB Local Loopback Fault"},
    		{ 0x08, "PB Remote Loopback Fault"},
    		{ 0x10, "PB Barrier Data Error"},
    		{ 0x20, "PB ADC Not Ready"},
    		{ 0x40, "PB MSP_Temp Over"},
    		{ 0x80, "PB MSP Temp Under"}
        }
    }
    
    VARIABLE device_specific_status_21 //wrd_SB_Diagn1
    {
        REDEFINE LABEL "SB Diagnostics 1"; 
        REDEFINE HELP "SB Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "SB AVDD Status Error"},
    		{ 0x02, "SB TEMP Status Error"},
    		{ 0x04, "SB AIN1 Status Error"},
    		{ 0x08, "SB AIN2 Status Error"},
    		{ 0x10, "SB AIN3 Status Error"},
    		{ 0x20, "SB ADC Not Responded"},
    		{ 0x40, "SB ADC Temp Over"},
    		{ 0x80, "SB ADC Temp Under"}
        }
    }
    
    VARIABLE device_specific_status_20 //wrd_SB_Diagn2
    {
        REDEFINE LABEL "SB Diagnostics 2"; 
        REDEFINE HELP "SB Diagnostics";
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "SB Head Temp Over"},
    		{ 0x02, "SB Head Temp Under"}
        }
    }

    VARIABLE analog_channel_saturated1
    {
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "Analog Channel 1"},
    		{ 0x02, "Analog Channel 2"},
    		{ 0x04, "Analog Channel 3"},
    		{ 0x08, "Analog Channel 4"}
        }
    }

    VARIABLE analog_channel_fixed1
    {
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "Analog Channel 1"},
    		{ 0x02, "Analog Channel 2"},
    		{ 0x04, "Analog Channel 3"},
    		{ 0x08, "Analog Channel 4"}
        }
    }

    COMMAND read_additional_device_status
    {
        REDEFINE TRANSACTION
        {
            REQUEST {}
            REPLY
            {
                response_code, device_status, 
                device_specific_status_0, device_specific_status_1, 
                device_specific_status_2/*wrd_SSMod_H*/, device_specific_status_3/*wrd_SSMod_L*/, 
                device_specific_status_4, device_specific_status_5,
    
                0x00/*extended_fld_device_status*/, 0x00/*operatingMode*/,             
                0x00/*analog_channel_saturated3*/, 0x00/*analog_channel_saturated2*/, analog_channel_saturated1,
                0x00/*analog_channel_fixed3*/, 0x00/*analog_channel_fixed2*/, analog_channel_fixed1,
    
                device_specific_status_14/*wrd_AI_Memory_Diagn*/, 
                device_specific_status_15/*wrd_PB_Memory_Diagn*/, 
                device_specific_status_16/*wrd_SB_Memory_Diagn*/, 
                device_specific_status_17/*wrd_TB_Memory_Diagn*/,
                device_specific_status_18 /*wrd_AI_Diagn*/,
                device_specific_status_19 /*wrd_PB_Diagn*/, 
                device_specific_status_20 /*wrd_SB_Diagn2*/, 
                device_specific_status_21/*wrd_SB_Diagn1*/,//wrd_TB_Diagn
    
                device_specific_status_22, 
                device_specific_status_23, device_specific_status_24
            }
        }
    }



    VARIABLE write_protect
    {  
        REDEFINE HANDLING READ & WRITE;
        REDEFINE TYPE ENUMERATED
        {
            WRITE_PROTECT_CODE(0),  // NO
            WRITE_PROTECT_CODE(1),  // YES 
            WRITE_PROTECT_CODE(253)  // SPECIAL (MID)
        }
    }
    
    VARIABLE response_preambles
    {  
        REDEFINE HANDLING WRITE; //READ & WRITE;
    } 

    VARIABLE transfer_function
    {
        REDEFINE HANDLING READ & WRITE;
        REDEFINE TYPE ENUMERATED
        {
            TRANSFER_FUNCTION_CODE (0), // LINEAR   
            TRANSFER_FUNCTION_CODE (1), // SQRT
            TRANSFER_FUNCTION_CODE (4), // SPECIAL
            TRANSFER_FUNCTION_CODE (5) // SQUARE
        }
    } 
    }
}

IMPORT STANDARD _PRESSURE_UNIVERSAL_5, DEVICE_REVISION 2, DD_REVISION 1
{
    /* Pressure Common Interoperable Device Description */

    VARIABLE flange_type;
    VARIABLE o_ring_material;

    REDEFINITIONS
    {
        VARIABLE flange_type
        {
            REDEFINE TYPE ENUMERATED
            {

                {15, "S-P acc. DIN 2512 Form N"},
                {16, "S-P acc. DIN 2526 Form E"},
                {17, "S-P acc. ANSI"},
                {18, "S-Ch acc. DIN 2526 Form B"},
                {19, "S-Ch acc. ANSI"},
                {20, "S-T / T=50 acc. DIN 2512 Form N"},
                {21, "S-T / T=50 acc. DIN 2526 Form E"},
                {22, "S-T / T=50 acc. ANSI"},
                {23, "S-T / T=100 acc. DIN 2512 Form N"},
                {24, "S-T / T=100 acc. DIN 2526 Form E"},
                {25, "S-T / T=100 acc. ANSI"},
                {26, "S-T / T=150 acc. DIN 2512 Form N"},
                {27, "S-T / T=150 acc. DIN 2526 Form E"},
                {28, "S-T / T=150 acc. ANSI"},
                {29, "S-T / T=200 acc. DIN 2512 Form N"},
                {30, "S-T / T=200 acc. DIN 2526 Form E"},
                {31, "S-T / T=200 acc. ANSI"},
                {32, "S-TK-P"},
                {33, "S-TK-P"},
                {34, "S-Comp"},
                {35, "S-CompCh"},
                {36, "S-Mazut"},
                {37, "S-Clamp"},
                {38, "S-DIN"},
                {39, "S-SMS 38"},
                {40, "S-SMS 50"},
                {41, "S-SMSG 38"},
                {42, "S-SMSG 50"},
                {43, "S-Homogenizer"},
                {44, "S-Varivent"},
                {45, "S-Level 25"},
                {46, "S-Level 50"},                
                {47, "S-DRD"},
                {48, "S-CG1"},
                {49, "S-CGS1"},
                {50, "S-CG1 1"},
                {51, "S-M48x3"},
                {52, "P-Bitum"},
                {53, "S-RCM30x2"},
                {54, "S-RCM30x1,5"},
                {55, "S-RCG1"},
            	{250,  [not_used] },
            	{251,  [none] },
            	{252,  [unknown] },
            	{253,  [special] }
            }
            REDEFINE HANDLING READ;
        }

        VARIABLE o_ring_material
        {
            REDEFINE TYPE ENUMERATED
            {
            	{ 10, "PTFE"},
                { 12, "NBR"},
                { 13, "EPDM"},
                { 14, "Silicon"},
                { 15, "FPM"},        	
            	{250,  [not_used] },
            	{251,  [none] },
            	{252,  [unknown] },
            	{253,  [special] }
            }
            REDEFINE HANDLING READ;
        }
    }
}


VARIABLE nominal_measuring_range        
{
	LABEL           "Nominal Measuring Range";
	HELP            "Nominal Measuring Range";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "-250  250 Pa"},
        		{2, "-700  700 Pa"},
        		{3, "-2500  2500 Pa"},
        		{4, "0  2500 Pa"},
        		{5, "-0,25  0,25 kPa"},	
        		{6, "-0,7  0,7 kPa"},
        		{7, "-2,5  2,5 kPa"},
        		{8, "0  2,5 kPa"},
        		{9, "-0,5  7 kPa"},
        		{10, "-1,5  7 kPa"},
        		{11, "-10  10 kPa"},
        		{12, "-16  16 kPa"},
        		{13, "0  25 kPa"},
        		{14, "-50  50 kPa"},
        		{15, "-100  600 kPa"},
        		{16, "-160  200 kPa"},
        		{17, "-160  1600 kPa"},
        		{18, "0  100 kPa"},
        		{19, "0  200 kPa"},
        		{20, "-100  150 kPa"},
        		{21, "0  0,7 MPa"},
        		{22, "0  1,6 MPa"},
        		{23, "0  2,5 MPa"},
        		{24, "0  7 MPa"},
        		{25, "0  16 MPa"},
        		{26, "0  30 MPa"},
        		{27, "0  60 MPa"},
        		{28, "0  100 MPa"},
        		{29, "0  110 kPa ABS"},
        		{30, "0  0,7 MPa ABS"},
        		{31, "0  2,5 MPa ABS"},
        		{32, "0  7 MPa ABS"},
        		{33, "0  -6000 mmH2O"},
        		{34, "0  -1600 mmH2O"},
        		{35, "0  1,5 mH2O"},
        		{36, "0  10 mH2O"},
        		{37, "0  100 mH2O"},
            	{250,  [not_used] },
            	{251,  [none] },
            	{252,  [unknown] },
            	{253,  [special] }

	}
	HANDLING        READ;
}


VARIABLE process_connection_type        
{
	LABEL           "Process Connection Type";
	HELP            "Process Connection Type";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "M20x1,5"},
        		{2, "P"},
        		{3, "CM30x2"},
        		{4, "CM20x1,5"},
        		{5, "G 1/2"},	
        		{6, "G 1/4"},
        		{7, "GP"},
        		{8, "CG1"},
        		{9, "CG 1/2"},
        		{10, "RM"},
        		{11, "RG"},
        		{12, "C"},
        		{13, "PCV"},
        		{14, "1/2 NPT M"},
        		{15, "1/2 NPT F"},
        		{16, "1/1 NPT M"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               } 
    }
	HANDLING        READ;
}

VARIABLE process_connection_material        
{
	LABEL           "Process Connection Material";
	HELP            "Process Connection Material";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        { 2,   [stainless_steel_316], [stainless_steel_316_help] },
        { 3,   [hastelloy_c],         [hastelloy_c_help] },
        { 4,   [monel],           [monel_help] },
        { 5,   [tantalum],        [tantalum_help] },
        { 6,   [titanium],        [titanium_help] },
        { 19,  [stainless_steel_316l_sup],[stainless_steel_316l_help] },
        { 40,  "hastelloy c / stainless steel 316"},
        { 41,  "hastelloy c / stainless steel 316L"},
        {250,   [not_used]              },
        {251,   [reserved]              },
        {252,   [unknown]               },
        {253,   [special]               } 
       
    }
	HANDLING        READ;
}

VARIABLE sensor_filling_fluid
{
	LABEL           "Sensor Filling Fluid";
	HELP            "Sensor Filling Fluid";
	CLASS           DEVICE;
    TYPE ENUMERATED
            {
                {3, "AK20"},
                {4, "DC550"},
                {5, "M20"},
                {6, "FS-5"},
        		{56, "Neobee"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               }            
             }
             HANDLING READ;
}

VARIABLE static_pressure
{
	LABEL           "Static Pressure";
	HELP            "Static Pressure";
	CLASS           DEVICE;
    TYPE ENUMERATED
            {
                {1, "35 kPa"},
                {2, "100 kPa"},
                {3, "1 MPa"},
                {4, "4 MPa"},
                {5, "10 MPa"},
                {6, "16 MPa"},
                {7, "25 MPa"},
                {8, "32 MPa"},
        		{9, "40 MPa"},
                {10, "42 MPa"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               }            
             }
             HANDLING READ;
}


VARIABLE diaphragm_seal_size
{
	LABEL           "Diaphragm Seal Size";
	HELP            "Diaphragm Seal Size";
	CLASS           DEVICE;
    TYPE ENUMERATED
            {
                {1, "DN25"},
                {2, "DN40"},
                {3, "DN50"},
                {4, "DN65"},
                {5, "DN80"},
                {6, "DN100"},
                {7, "A109"},
                {8, "1"},
        		{9, "1 1/2"},
                {10, "2"},
                {11, "3"},
                {12, "phi 50"},
        		{13, "phi 75"},
                {14, "phi 100"},

        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               }            
             }
             HANDLING READ;
}

VARIABLE seal_diaphragm_material        
{
	LABEL           "Seal Diaphragm Material";
	HELP            "Seal Diaphragm Material";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        { 2,   [stainless_steel_316], [stainless_steel_316_help] },
        { 3,   [hastelloy_c],         [hastelloy_c_help] },
        { 4,   [monel],           [monel_help] },
        { 5,   [tantalum],        [tantalum_help] },
        { 6,   [titanium],        [titanium_help] },
        { 10,  "teflon"},
        { 19,  [stainless_steel_316l_sup],[stainless_steel_316l_help] },

        {250,   [not_used]              },
        {251,   [reserved]              },
        {252,   [unknown]               },
        {253,   [special]               } 
       
    }
	HANDLING        READ;
}

VARIABLE seal_contact_face_material        
{
	LABEL           "Seal Contact Face Material";
	HELP            "Seal Contact Face Material";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        { 2,   [stainless_steel_316], [stainless_steel_316_help] },
        { 3,   [hastelloy_c],         [hastelloy_c_help] },
        { 4,   [monel],           [monel_help] },
        { 5,   [tantalum],        [tantalum_help] },
        { 6,   [titanium],        [titanium_help] },
        { 10,  "teflon"},
        { 19,  [stainless_steel_316l_sup],[stainless_steel_316l_help] },
        { 26,  [nickel],          [nickel_help] },
        {250,   [not_used]              },
        {251,   [reserved]              },
        {252,   [unknown]               },
        {253,   [special]               } 
       
    }
	HANDLING        READ;
}

VARIABLE seal_filling_fluid
{
	LABEL           "Seal Filling Fluid";
	HELP            "Seal Filling Fluid";
	CLASS           DEVICE;
    TYPE ENUMERATED
            {
                {3, "AK20"},
                {4, "DC550"},
                {5, "M20"},
                {6, "FS-5"},
        		{56, "Neobee"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               }            
             }
             HANDLING READ;
}

VARIABLE nominal_pressure        
{
	LABEL           "Nominal Pressure";
	HELP            "Nominal Pressure";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "PN2,5"},
        		{2, "PN6"},
        		{3, "PN10"},
        		{4, "PN16"},
        		{5, "PN20"},	
        		{6, "PN25"},
        		{7, "PN40"},
        		{8, "PN50"},
        		{9, "PN63"},
        		{10, "PN100"},
        		{11, "PN110"},
        		{12, "PN150"},
        		{13, "PN160"},
        		{14, "PN260"},
        		{15, "150Lb"},
        		{16, "300Lb"},
        		{17, "600Lb"},
        		{18, "1500Lb"},
        		{19, "2500Lb"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               } 
	}
	HANDLING        READ;
}

VARIABLE length_capillary_H        
{
	LABEL           "Length Capillary H";
	HELP            "Length Capillary H";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "0,5m"},
        		{2, "1m"},
        		{3, "1,5m"},
        		{4, "2m"},
        		{5, "3m"},	
        		{6, "4m"},
        		{7, "5m"},
        		{8, "6m"},
        		{9, "7m"},
        		{10, "8m"},
        		{11, "9m"},
        		{12, "10m"},
        		{13, "11m"},
        		{14, "12m"},
        		{15, "13m"},
        		{16, "14m"},
        		{17, "15m"},
        		{18, "16m"},
        		{19, "17m"},
        		{20, "18m"},
        		{21, "19m"},
        		{22, "20m"},
        		{23, "21m"},
        		{24, "22m"},
        		{25, "23m"},
        		{26, "24m"},
        		{27, "25m"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               } 
	}
	HANDLING        READ;
}

VARIABLE length_capillary_L        
{
	LABEL           "Length Capillary L";
	HELP            "Length Capillary L";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "0,5m"},
        		{2, "1m"},
        		{3, "1,5m"},
        		{4, "2m"},
        		{5, "3m"},	
        		{6, "4m"},
        		{7, "5m"},
        		{8, "6m"},
        		{9, "7m"},
        		{10, "8m"},
        		{11, "9m"},
        		{12, "10m"},
        		{13, "11m"},
        		{14, "12m"},
        		{15, "13m"},
        		{16, "14m"},
        		{17, "15m"},
        		{18, "16m"},
        		{19, "17m"},
        		{20, "18m"},
        		{21, "19m"},
        		{22, "20m"},
        		{23, "21m"},
        		{24, "22m"},
        		{25, "23m"},
        		{26, "24m"},
        		{27, "25m"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               } 
	}
	HANDLING        READ;
}

VARIABLE configuration_of_seal        
{
	LABEL           "Configuration of Seal";
	HELP            "Configuration of Seal";
	CLASS           DEVICE;
	TYPE            ENUMERATED
	{
        		{1, "H"},
        		{2, "L"},
        		{3, "H_L remote seal"},
        		{4, "H remote seal_L"},
        		{5, "H remote seal_L remote seal"},
        		{250,   [not_used]              },
        		{251,   [reserved]              },
        		{252,   [unknown]               },
        		{253,   [special]               } 
	}
	HANDLING        READ;
}



/*
            process_connection_type, process_connection_material, o_ring_material,
            sensor_filling_fluid, nominal_measuring_range, static_pressure,
            diaphragm_seal_size, flange_type, seal_diaphragm_material,
            seal_contact_face_material, seal_filling_fluid, nominal_pressure,
            length_capillary_H, length_capillary_L, configuration_of_seal
*/
/*************************************************************************************************
 * Dynamic Variables Configuration
 *************************************************************************************************/
VARIABLE pressureValue
{
    LABEL [pressure_value];
    HELP [digital_value_pressure_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.3f";
    }
}
 
VARIABLE pressureUnits
{
    LABEL [pressure_value_unit];
    HELP [digital_units_pressure_help];
    HANDLING READ & WRITE; //READ & WRITE;
    TYPE ENUMERATED
    {
		{ 1,   [InH2O],                 [inches_of_water_68_degrees_F_help]             },
		{ 2,   [InHg],                  [inches_of_mercury_0_degrees_C_help]            },
		{ 3,   [FtH2O],                 [feet_of_water_68_degrees_F_help]               },
		{ 4,   [mmH2O],                 [millimeters_of_water_68_degrees_F_help]        },
		{ 5,   [mmHg],                  [millimeters_of_mercury_0_degrees_C_help]       },
		{ 6,   [psi],                   [pounds_per_square_inch_help]                   },
		{ 7,   [bar],                   [bars_help]                                     },
		{ 8,   [mbar],                  [millibars_help]                                },
		{ 9,   [g_SqCm],                [grams_per_square_centimeter_help]              },
		{ 10,  [kg_SqCm],               [kilograms_per_square_centimeter_help]          },
		{ 11,  [PA],                    [pascals_help]                                  },
		{ 12,  [kPA],                   [kilopascals_help]                              },
		{ 13,  [torr],                  [torr_help]                                     },
		{ 14,  [ATM],                   [atmospheres_help]                              },
        { 171, "m H2O 4C",               ""                                              },
		{ 237, [mega_pascals],          [megapascals_help]                              },
		{ 238, [in_H2O_4_degrees_C],    [inches_of_water_4_degrees_C_help]              },
		{ 239, [mm_H2O_4_degrees_C],    [millimeters_of_water_4_degrees_C_help]         }
    }
}
                    
VARIABLE pressureUSL
{
    LABEL [pressure_upper_sensor_limit];
    HELP [upper_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.3f";
    }
}

VARIABLE pressureLSL
{
    LABEL [pressure_lower_sensor_limit];
    HELP [lower_sensor_limit_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.3f";
    }
}

VARIABLE pressureMinimumSpan
{
    LABEL [pressure_minimum_span];
    HELP [minimum_span_pressure_help];
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.3f";
    }
}

VARIABLE pressureDampingValue
{
    LABEL [pressure_damping_value];
    HELP  [seconds_damping_value_pressure_help];
    /* You will probably add a write command for this later
       usualy command 34 for Write Primary Variable Damping Value */
    HANDLING READ & WRITE;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE pressureSerialNumber
{
    LABEL [pressure_sensor_serial_number];
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";
    }
}

/****************************************************************
 * DEFINICJE DOPISANE Z DOKUMENTU MPC5-SKRCONA_INSTRUKCJA_OBSUGI.DOC
*****************************************************************/

// VARIABLE
VARIABLE current_lower_trim_point
{
	LABEL           "Lower current trim point";
	HELP            "Lower current trim point";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
    CONSTANT_UNIT   "mA";
	HANDLING READ;
}

VARIABLE current_upper_trim_point
{
	LABEL           "Upper current trim point";
	HELP            "Upper current trim point";      
    CLASS           CORRECTION;
	TYPE            FLOAT;
    CONSTANT_UNIT   "mA";
	HANDLING READ;
}

VARIABLE sensor_lower_trim_point
{
	LABEL           "Lower sensor trim point";
	HELP            "Applied process pressure at which the last low sensor trim was performed.";                                     //HELP !!!
	CLASS           LOCAL;
	TYPE            FLOAT ;
    //CONSTANT_UNIT   "mA";
	HANDLING        READ & WRITE;
}

VARIABLE sensor_upper_trim_point
{
	LABEL           "Upper sensor trim point";
	HELP            "Applied process pressure at which the last upper sensor trim was performed.";                                     //HELP !!!
	CLASS           LOCAL;
	TYPE            FLOAT;
	HANDLING        READ & WRITE;
}

VARIABLE current_units
{
    LABEL               "Current units";
    HELP                "Current units";
    CLASS               CORRECTION;
    TYPE                ENUMERATED
    {
		{ 39,  [mA]}
    }
    HANDLING    READ;
}

VARIABLE kind_of_trim
{
	LABEL           "Kind of trim";
    HELP            "User calibrations (sensor calibrations) are replaced by the original factory calibrations.";   
    CLASS           INPUT;
    HANDLING        WRITE; 
    TYPE            ENUMERATED
	{
		{ 0,  "undo zero trim" },
		{ 1,  "sensor trim recall to factory settings" },
		{ 2,  "analog output trim recall to factory settings" }
	}
}

VARIABLE product_code                                /* Table 26 */
{
	LABEL           "Product code";
    HELP            "Product code as generated from the product catalogue. "
                    "It is related to the pressure trasmitter and its optional. "
                    "A modification of the product code will not affect device functionally.";  
	CLASS           DEVICE;
	TYPE            ASCII(16);
    HANDLING READ;
}


VARIABLE separator_code                                /* Table 26 */
{
	LABEL           "Separator code";
    HELP            "Product code as generated from the product catalogue. "
                    "It is related to the Remote Seal connected to the positive side of the transmitter. "
                    "If no remote seal connected the code is blank. "
                    "A modification of the product code will not affect device functionally.";

	CLASS           DEVICE;
	TYPE            ASCII(16);
    HANDLING READ;
}

VARIABLE manifold_code                                /* Table 26 */
{
	LABEL           "Manifold code";
	HELP            "Product code as generated from the product catalogue. "
                    "It is related to the Remote Seal connected to the negative "
                    "side of the transmitter.If no remote seal connected the code is blank. "
                    "A modification of the product code will not affect device functionally "; 
	CLASS           DEVICE;
	TYPE            ASCII(16);
    HANDLING READ;
}

VARIABLE long_tag                                 /* Table 26 */
{
	LABEL           "Long tag";
	HELP            "Tag 24 ASCII character";  
    CLASS           DEVICE;
	TYPE            ASCII(24);
    HANDLING READ & WRITE;
}

VARIABLE startpoint_rad                                 
{
	LABEL           "Startpoint rad";
    HELP            "Determines the transition from linear resp. 4mA-constant to square root (Transfer Function).";  
    CLASS           INPUT;
    TYPE            FLOAT
	{
	    DISPLAY_FORMAT "5.2f";
    }
    
    CONSTANT_UNIT    [Percent];
	HANDLING READ & WRITE;
}


VARIABLE electronic_temp_units 
{
    LABEL               "Unit";
    HELP                "Units code selectable for the Electronic Temperature variable ";  
    CLASS               INPUT;
    TYPE                ENUMERATED
    {
    	{ 32,  [degC],                  [degrees_celsius_help] },
		{ 33,  [degF],                  [degrees_fahrenheit_help] },
		{ 34,  [degR],                  [degrees_rankine_help] },
		{ 35,  [Kelvin],                [degrees_kelvin_help] }
	}
	HANDLING READ;
}

VARIABLE electronic_temp_value
{
    LABEL               "Value";
    HELP                [electronics_temperature_help];
    CLASS               CORRECTION & INPUT;
    TYPE                FLOAT
    {
		DISPLAY_FORMAT ".1f";
    }
    HANDLING    READ;
}
VARIABLE temp_glowicy_value
{
    LABEL               "Value";
    HELP                [electronics_temperature_help];
    CLASS               CORRECTION & INPUT;
    TYPE                FLOAT
    {
		DISPLAY_FORMAT ".1f";
    }
    HANDLING    READ;
}

VARIABLE temp_adc_value
{
    LABEL               "Value";
    HELP                [electronics_temperature_help];
    CLASS               CORRECTION & INPUT;
    TYPE                FLOAT
    {
		DISPLAY_FORMAT ".1f";
    }
    HANDLING    READ;
}

/* This is the minimum set of members that any device variable collection must have */
COLLECTION OF VARIABLE press
{
    LABEL [pressure];
    HELP [pressure_help];
    MEMBERS
    {   
        /* Sensor Correction Information */
        DIGITAL_VALUE,              pressureValue,              [blank],                [digital_value_help];
        DIGITAL_UNITS,              pressureUnits,              [units],                [digital_units_help];

        UPPER_SENSOR_LIMIT,         pressureUSL,                [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         pressureLSL,                [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               pressureMinimumSpan,        [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              pressureDampingValue,       [damping_value],        [seconds_damping_value_help];

        /* Device Information */
        SENSOR_SERIAL_NUMBER,       pressureSerialNumber,       [sensor_serial_number], [sensor_serial_number_help];
    }
}

COLLECTION OF VARIABLE temp_glowicy
{
    LABEL "Device temperature";                         
    HELP "Device temperature";
    MEMBERS
    {   
        /* Sensor Correction Information */
        DIGITAL_VALUE,              temp_glowicy_value,              [blank],                [digital_value_help];
        DIGITAL_UNITS,              electronic_temp_units,              [units],                [digital_units_help];
    }
}

COLLECTION OF VARIABLE temp_przetwornika
{
    LABEL "Device temperature";                         
    HELP "Device temperature";
    MEMBERS
    {   
        /* Sensor Correction Information */
        DIGITAL_VALUE,              electronic_temp_value,              [blank],                [digital_value_help];
        DIGITAL_UNITS,              electronic_temp_units,              [units],                [digital_units_help];
    }
}

COLLECTION OF VARIABLE temp_adc
{
    LABEL "";                         
    HELP "";
    MEMBERS
    {   
        /* Sensor Correction Information */
        DIGITAL_VALUE,              temp_adc_value,              [blank],                [digital_value_help];
        DIGITAL_UNITS,              electronic_temp_units,              [units],                [digital_units_help];
    }
}

ARRAY OF COLLECTION deviceVariables 
{
    ELEMENTS
    {
        0, press, [pv];
        1, temp_glowicy, [sv];
        2, temp_przetwornika, [tv];         //tutja jest blad
        3, temp_adc, [qv];
    }
}   
 /*******************************************************************************************************************
 dodatkowe zmienne
 ********************************************************************************************************************/
//change security code
VARIABLE old_customer_code
{
    LABEL "Old customer security code";
    HELP  "Old customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;
    /*POST_EDIT_ACTIONS
    {
        m_246
    } */
}

VARIABLE new_customer_code
{
    LABEL "New customer security code";
    HELP  "New customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;
    POST_EDIT_ACTIONS
    {
        m_246
    }
}

METHOD m_246
{
    LABEL "m_246";
    HELP  "";
    DEFINITION 
    {  
        send_command(246);
    }
}


VARIABLE protect_code
{
    LABEL "Customer code";
    HELP  "Customer code";
    CLASS DEVICE;
    HANDLING WRITE;
    DEFAULT_VALUE 0;
    TYPE INTEGER (4);
    /*POST_EDIT_ACTIONS
    {
        set_protect
    } */
}                                                           

METHOD set_protect
{
    LABEL "Set protect code";
    HELP  "";
    DEFINITION 
    { 
      ACKNOWLEDGE("Press OK to Set Protect Code");
      send_command(247);
    }
}

VARIABLE x20                                 
{
	LABEL           "x20";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
    DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  100; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x19                                 
{
	LABEL           "x19";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
    DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
    	//MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
   	CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x18                                 
{
	LABEL           "x18";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
    DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";	
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x17                                 
{
	LABEL           "x17";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x16                                 
{
	LABEL           "x16";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
    DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
    	//MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x15                                 
{
	LABEL           "x15";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
    	//MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x14                                 
{
	LABEL           "x14";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x13                                 
{
	LABEL           "x13";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x12                                 
{
	LABEL           "x12";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x11                                 
{
	LABEL           "x11";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x10                                 
{
	LABEL           "x10";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x9                                 
{
	LABEL           "x9";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1; //00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x8                                 
{
	LABEL           "x8";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

VARIABLE x7                                 
{
	LABEL           "x7";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x6                                 
{
	LABEL           "x6";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x5                                 
{
	LABEL           "x5";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;//00;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x4                                 
{
	LABEL           "x4";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x3                                 
{
	LABEL           "x3";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x2                                 
{
	LABEL           "x2";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x1                                 
{
	LABEL           "x1";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE x0                                 
{
	LABEL           "x0";
	HELP            "Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}


VARIABLE y20                                 
{
	LABEL           "y20";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y19                                 
{
	LABEL           "y19";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y18                                 
{
	LABEL           "y18";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y17                                 
{
	LABEL          "y17";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y16                                 
{
	LABEL           "y16";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y15                                 
{
	LABEL           "y15";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y14                                 
{
	LABEL           "y14";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}


VARIABLE y13                                 
{
	LABEL           "y13";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}


VARIABLE y12                                 
{
	LABEL           "y12";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y11                                 
{
	LABEL           "y11";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y10                                 
{
	LABEL           "y10";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y9                                 
{
	LABEL           "y9";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y8                                 
{
	LABEL           "y8";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y7                                 
{
	LABEL           "y7";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y6                                 
{
	LABEL           "y6";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y5                                 
{
	LABEL           "y5";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y4                                 
{
	LABEL           "y4";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y3                                 
{
	LABEL           "y3";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y2                                 
{
	LABEL           "y2";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}

VARIABLE y1
{
	LABEL           "y1";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;}
            
VARIABLE y0
{
	LABEL           "y0";
	HELP            "Double Polynomial Coefficient";
	CLASS           INPUT;
	DEFAULT_VALUE   1;
	TYPE            FLOAT
	{
		DISPLAY_FORMAT  "3.1f";
		SCALING_FACTOR 100;
	    //MIN_VALUE  0;
	    //MAX_VALUE  1;
	}
    CONSTANT_UNIT       [Percent];
	HANDLING        READ & WRITE;
}

/******************************************************************************************/

VARIABLE local_keys_mode_control_codes
{
	LABEL           "Local Operation";
	HELP            "Local Operation";
    CLASS           LOCAL_DISPLAY;
    DEFAULT_VALUE   0;
	TYPE            ENUMERATED
    {
  		{ 0,    "Enabled" },
		{ 1,    "Disabled" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_information_configuration
{
    LABEL               "Meter Information Configuration";
    HELP                [meter_information_configuration_help];
    CLASS               LOCAL_DISPLAY;
    TYPE                ENUMERATED
    {
		{0,     [not_installed]},
		{1,     "Integral LCD" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_display_mode
{
    LABEL               "Meter display mode";
    HELP                "Meter display mode";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
    {
  	    { 0, "Unit On"},
   	    { 1, "Unit Off"}
    }
  HANDLING    READ & WRITE;
}


VARIABLE meter_display_electronics_bias_control
{
    LABEL               "Meter display contrast";
    HELP                "Meter display contrast";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
	{
        {0, "NOT USED"}    
	}
    HANDLING    READ & WRITE;
}


VARIABLE LCD1_display_variable
{
    LABEL               "LCD1 display variable";
    HELP                "LCD1 display variable";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
 		{0,     "Current"},
		{1,     "Percent of Range" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE LCD2_display_variable
{
    LABEL               "LCD2 display variable";
    HELP                "LCD2 display variable";
    CLASS               LOCAL_DISPLAY;
	//DEFAULT_VALUE       0;
    TYPE                ENUMERATED(2)
    {
		{2,     "Pressure" },
		{3,     "User Rerange"},
        {0,     "Pressure, no unit displayed" },
        {1,     "User Rerange, no unit displayed"}
    }
    HANDLING    READ & WRITE;
}
VARIABLE LCD_gap
{
    LABEL               "LCD gap";
    HELP                "LCD gap";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
            {0,     "GAP"}
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_display_variable_decimal_point
{
    LABEL               "Meter display decimal point";
    HELP                "Meter display decimal point";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       6;
    TYPE                ENUMERATED
    {
        {1,     "[.XXXXX]" },
		{2,     "[X.XXXX]" },
		{3,     "[XX.XXX]" },
		{4,     "[XXX.XX]" },
		{5,     "[XXXX.X]" },
		{6,     "[XXXXX.]" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE cmd128_empty_byte
{
    LABEL               "Empty Byte";
    HELP                "Empty Byte";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
            {0,     "Empty Byte"}
    }
    HANDLING    READ;
}

VARIABLE cmd141_byte0        /* U8 */
{
    LABEL               "cmd141_byte0";
    HELP                "cmd141_byte0";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cmd141_byte1        /* U8 */
{
    LABEL               "cmd141_byte1";
    HELP                "cmd141_byte1";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cmd141_byte2        /* U8 */
{
    LABEL               "cmd141_byte2";
    HELP                "cmd141_byte2";
    CLASS               DEVICE;
    HANDLING            READ & WRITE;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE hart_modem_state
{
    LABEL               "HART modem error";
    HELP                "HART modem state alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE ADC7794_state
{
    LABEL               "ADC7794 error";
    HELP                "ADC7794 state alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE EEPROM_state
{
    LABEL               "EEPROM, RAM error";
    HELP                "EEPROM & RAM state alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE oscillator_state
{
    LABEL               "32768Hz oscillator error";
    HELP                "32768Hz oscillator state alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE DS33_state
{
    LABEL               "DS33 error";
    HELP                "DS33 state";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE cmd141_empty_bit
{
    LABEL               "empty_bit";
    HELP                "empty_bit";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "empty_bit" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE current_alarm
{
    LABEL               "Current Alarm";
    HELP                "Current Alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "HIGH (22 mA)" },       //Alarm Current
		{0x01,     "LOW  (3,6 mA)" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE current_range_mode
{
    LABEL               "Current Range Mode";
    HELP                "Current Range Mode";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "NORMAL (3,920,5 mA)" }, //Current Range Mode 
		{0x01,     "NAMUR (3,8  20,5 mA)" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE    users_unit
{
	LABEL           "Users Unit";
    HELP            "Display Unit - Unit that is displayed on the LCD Display";
	CLASS           DEVICE;
	TYPE            ASCII(7);
    HANDLING READ & WRITE;
}

VARIABLE rearrange_shift
{
	LABEL           "Rearrange Shift";
	HELP            "Rearrange Shift";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}

VARIABLE rearrange_ampl
{
	LABEL           "Rearrange Ampl";
	HELP            "Rearrange Ampl";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}
 
VARIABLE channel_number
{
    LABEL "Channel Number";
    HELP  "";
    CLASS LOCAL;
    HANDLING WRITE;   //READ &
    TYPE ENUMERATED 
    {
		{0, "0"},
        {1, "1"}		
    }
    DEFAULT_VALUE 1;
}

/*VARIABLE wrd_SSMod_H
{*/
    //LABEL "Dev. Spec Status Byte 2"; //"wrd_SSMod_H";
    //HELP "Device Specific Status Byte 2";
    //CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    //HANDLING READ;
    //TYPE BIT_ENUMERATED //UNSIGNED_INTEGER(1);
    /*{
		{ 0x01, "Sensor Failure"},
		{ 0x02, "Sensor Not Connected"},
		{ 0x04, "Primary Variable Not Valid"},
		{ 0x08, "Primary Variable Out Of Limits"},
		{ 0x10, "Secondary Variable Out Of Limits"},
		{ 0x20, "Analog Output Saturated"},
		{ 0x40, "Output Current Fixed"},
		{ 0x80, "Hot Start Occure"} 
    }                           
    POST_READ_ACTIONS
    {
         m_wrd_SSMod_H
    }
}*/

METHOD m_wrd_SSMod_H
{
    LABEL "";
    HELP  "";
    DEFINITION 
    { 
        float val;
        val = 0;
    }
}

VARIABLE wrd_SSMod_H_2
{
    LABEL "Dev. Spec Status Byte 2"; 
    HELP "Device Specific Status Byte 2";
    CLASS LOCAL & DIAGNOSTIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED 
    {        
		{ 0x01, "Sensor Failure"},
		{ 0x02, "Sensor Not Connected"},
		{ 0x04, "Primary Variable Not Valid"},
		{ 0x08, "Primary Variable Out Of Limits"},
		{ 0x10, "Secondary Variable Out Of Limits"},
		{ 0x20, "Analog Output Saturated"},
		{ 0x40, "Output Current Fixed"},
		{ 0x80, "Hot Start Occure"}
        
    }                  
    PRE_EDIT_ACTIONS
    {
         m_wrd_SSMod_H_2
    }
}

METHOD m_wrd_SSMod_H_2
{
    //podczona pod eep_max_work_press (zmienna musi by int lub float, eby refresh si wywoa)

    LABEL "wrd_SSMod_H_2";
    HELP  "";
    DEFINITION 
    { 
      int  val;

      val =  ivar_value(device_specific_status_2);
      //iassign(wrd_SSMod_H_2,val);

      //ACKNOWLEDGE("ivar_value(device_specific_status_2) =  %{val}");
      val = val ^ 0xF8;
      //ACKNOWLEDGE("val = val ^ 0xF8 =  %{val}");
      iassign(wrd_SSMod_H_2,val);
      //ACKNOWLEDGE("wrd_SSMod_H_2 =  %{val}");
      //save_values();       
     }
}


/*VARIABLE wrd_SSMod_L
{*/
    //LABEL "Dev. Spec Status Byte 3"; //"wrd_SSMod_L";
    /*HELP "Device Specific Status Byte 3";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "RAM Test Error"},
		{ 0x02, "Flash CRC Error"},
		{ 0x04, "Bad CRC In Segment INFO"},
		{ 0x08, "Oscillator Fault"},
		{ 0x10, "HT430 Init Error"},
		{ 0x20, "ADC Interface Master Error"},
		{ 0x40, "ADC Interface Slave Error"},
		{ 0x80, "ADC Not Responded"}
    }
}*/

/*VARIABLE wrd_AI_Memory_Diagn
{*/
    //LABEL "AI Memory Diagnostics"; //"AI Memory Diagnostic";
    /*HELP "AI Memory Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "INFO Fault"},
		{ 0x02, "INFO Recovery"},
		{ 0x04, "INFO Recovery Fault"},
		{ 0x08, "Backup Info Fault"},
		{ 0x10, "Backup Info Recovery"},
		{ 0x20, "Backup Info Recovery Fault"},*/
		//{ 0x40, "Flash Consistency Fault"}//,
		//{ 0x80, "ADC_NOT_RESPONDED"}
    //}
//}

//VARIABLE wrd_PB_Memory_Diagn
//{
//    LABEL "PB Memory Diagnostics"; //"PB Memory Diagnostic";
/*    HELP "PB Memory Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "INFO Fault"},
		{ 0x02, "INFO Recovery"},
		{ 0x04, "INFO Recovery Fault"},
		{ 0x08, "Backup Info Fault"},
		{ 0x10, "Backup Info Recovery"},
		{ 0x20, "Backup Info Recovery Fault"},*/
//		{ 0x40, "Flash Consistency Fault"}//,
		//{ 0x80, "ADC_NOT_RESPONDED"}
//    }
//}
//VARIABLE wrd_SB_Memory_Diagn
//{
   // LABEL "SB Memory Diagnostics"; //"SB Memory Diagnostic";
    /*HELP "SB Memory Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "INFO Fault"},
		{ 0x02, "INFO Recovery"},
		{ 0x04, "INFO Recovery Fault"},
		{ 0x08, "Backup Info Fault"},
		{ 0x10, "Backup Info Recovery"},
		{ 0x20, "Backup Info Recovery Fault"},*/
		//{ 0x40, "Flash Consistency Fault"}//,
		//{ 0x80, "ADC_NOT_RESPONDED"}
    //}
//}
//VARIABLE wrd_TB_Memory_Diagn
//{
    //LABEL "TB Memory Diagnostics"; //"TB Memory Diagnostic";
    /*HELP "TB Memory Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "INFO Fault"},
		{ 0x02, "INFO Recovery"},
		{ 0x04, "INFO Recovery Fault"},
		{ 0x08, "Backup Info Fault"},
		{ 0x10, "Backup Info Recovery"},
		{ 0x20, "Backup Info Recovery Fault"},*/
		//{ 0x40, "Flash Consistency Fault"}//,
		//{ 0x80, "ADC_NOT_RESPONDED"}
    //}
//}

/*VARIABLE wrd_PB_Diagn
{
    LABEL "PB Diagnostics"; 
    HELP "PB Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "PB LFXT1 Fault"},
		{ 0x02, "PB Hart Fault"},
		{ 0x04, "PB Local Loopback Fault"},
		{ 0x08, "PB Remote Loopback Fault"},
		{ 0x10, "PB Barrier Data Error"},
		{ 0x20, "PB ADC Not Ready"},
		{ 0x40, "PB MSP_Temp Over"},
		{ 0x80, "PB MSP Temp Under"}
    }
}

VARIABLE wrd_SB_Diagn1
{
    LABEL "SB Diagnostics 1"; 
    HELP "SB Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "SB AVDD Status Error"},
		{ 0x02, "SB TEMP Status Error"},
		{ 0x04, "SB AIN1 Status Error"},
		{ 0x08, "SB AIN2 Status Error"},
		{ 0x10, "SB AIN3 Status Error"},
		{ 0x20, "SB ADC Not Responded"},
		{ 0x40, "SB ADC Temp Over"},
		{ 0x80, "SB ADC Temp Under"}
    }
}

VARIABLE wrd_SB_Diagn2
{
    LABEL "SB Diagnostics 2"; 
    HELP "SB Diagnostics";
    CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
    HANDLING READ;
    TYPE BIT_ENUMERATED
    {
		{ 0x01, "SB Head Temp Over"},
		{ 0x02, "SB Head Temp Under"}
    }
}*/


VARIABLE eep_max_work_press_uc
/* U8, max_work_press_unit_code */
{
    LABEL "Max pres unit";
    HELP "Units code selectable for the Max working press parameter.";
    HANDLING READ;
    TYPE ENUMERATED
    {
		{ 1,   [InH2O],                 [inches_of_water_68_degrees_F_help]             },
		{ 2,   [InHg],                  [inches_of_mercury_0_degrees_C_help]            },
		{ 3,   [FtH2O],                 [feet_of_water_68_degrees_F_help]               },
		{ 4,   [mmH2O],                 [millimeters_of_water_68_degrees_F_help]        },
		{ 5,   [mmHg],                  [millimeters_of_mercury_0_degrees_C_help]       },
		{ 6,   [psi],                   [pounds_per_square_inch_help]                   },
		{ 7,   [bar],                   [bars_help]                                     },
		{ 8,   [mbar],                  [millibars_help]                                },
		{ 9,   [g_SqCm],                [grams_per_square_centimeter_help]              },
		{ 10,  [kg_SqCm],               [kilograms_per_square_centimeter_help]          },
		{ 11,  [PA],                    [pascals_help]                                  },
		{ 12,  [kPA],                   [kilopascals_help]                              },
		{ 13,  [torr],                  [torr_help]                                     },
		{ 14,  [ATM],                   [atmospheres_help]                              },
        { 171, "m H2O 4C",               ""                                              },
		{ 237, [mega_pascals],          [megapascals_help]                              },
		{ 238, [in_H2O_4_degrees_C],    [inches_of_water_4_degrees_C_help]              },
		{ 239, [mm_H2O_4_degrees_C],    [millimeters_of_water_4_degrees_C_help]         }
    }
}

VARIABLE eep_max_work_press
/* max_work_pressure, IEE754 float */
{   
    LABEL "Max work pres";
    HELP "Max process pressure applicable to the device for a correct working.";
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.2f";
    }
}

VARIABLE eep_min_work_press_uc
/*  U8, min_work_press_unit_code */
{   
    LABEL "Min pres unit";
    HELP "Units code selectable for the Min working press parameter.";
    HANDLING READ;
    TYPE ENUMERATED
    {
		{ 1,   [InH2O],                 [inches_of_water_68_degrees_F_help]             },
		{ 2,   [InHg],                  [inches_of_mercury_0_degrees_C_help]            },
		{ 3,   [FtH2O],                 [feet_of_water_68_degrees_F_help]               },
		{ 4,   [mmH2O],                 [millimeters_of_water_68_degrees_F_help]        },
		{ 5,   [mmHg],                  [millimeters_of_mercury_0_degrees_C_help]       },
		{ 6,   [psi],                   [pounds_per_square_inch_help]                   },
		{ 7,   [bar],                   [bars_help]                                     },
		{ 8,   [mbar],                  [millibars_help]                                },
		{ 9,   [g_SqCm],                [grams_per_square_centimeter_help]              },
		{ 10,  [kg_SqCm],               [kilograms_per_square_centimeter_help]          },
		{ 11,  [PA],                    [pascals_help]                                  },
		{ 12,  [kPA],                   [kilopascals_help]                              },
		{ 13,  [torr],                  [torr_help]                                     },
		{ 14,  [ATM],                   [atmospheres_help]                              },
        { 171, "m H2O 4C",               ""                                              },
		{ 237, [mega_pascals],          [megapascals_help]                              },
		{ 238, [in_H2O_4_degrees_C],    [inches_of_water_4_degrees_C_help]              },
		{ 239, [mm_H2O_4_degrees_C],    [millimeters_of_water_4_degrees_C_help]         }
    }
}


VARIABLE eep_min_work_press
/*  min_work_pressure, IEE754 float */
{
    LABEL "Min work pres";
    HELP "Min process pressure applicable to the device for a correct working.";
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.2f";
    }
}


VARIABLE eep_min_temp_unit_code
/* U8, min_temp_unit_code, zawsze [C] ! */
{
    LABEL "Min temp unit";
    HELP "Units code selectable for the Min temperature parameter.";
    HANDLING READ;
    DEFAULT_VALUE 32;
    TYPE ENUMERATED
    {
    	{ 32,  [degC],                  [degrees_celsius_help] },
		{ 33,  [degF],                  [degrees_fahrenheit_help] },
		{ 34,  [degR],                  [degrees_rankine_help] },
		{ 35,  [Kelvin],                [degrees_kelvin_help] }
	}
}

VARIABLE  eep_min_temp_value
/* min_temp_value, IEE754 float */
{
    LABEL "Min temp value";
    HELP "Min temperature applicable to the device for a correct working.";
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.2f";
    }
}

VARIABLE eep_max_temp_unit_code
/* U8, min_temp_unit_code, zawsze [C] ! */
{
    LABEL "Max temp unit";
    HELP "Units code selectable for the Max temperature parameter.";
    HANDLING READ;
    DEFAULT_VALUE 32;
    TYPE ENUMERATED
    {
    	{ 32,  [degC],                  [degrees_celsius_help] },
		{ 33,  [degF],                  [degrees_fahrenheit_help] },
		{ 34,  [degR],                  [degrees_rankine_help] },
		{ 35,  [Kelvin],                [degrees_kelvin_help] }
	}
}
VARIABLE eep_max_temp_value
/* min_temp_value, IEE754 float */
{
    LABEL "Max temp value";
    HELP "Max temperature applicable to the device for a correct working.";
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "6.2f";
    }
}

/************************************************************************************/


VARIABLE cpu_hardware_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "CPU hardware major revision";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_hardware_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "CPU hardware minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "CPU software major rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE cpu_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "CPU software minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE master_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "Master software major revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE master_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "Master software minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE slave_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "Slave software major revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE slave_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "Slave software minor revision.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE adc_hardware_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "ADC hardware major rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE adc_hardware_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "ADC hardware minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE hart_software_major_revision        /* U8 */
{
    LABEL "Major";
    HELP "HART software major rev.";
    HANDLING READ;
    TYPE INTEGER (1)
    {
        DISPLAY_FORMAT "2d";
    }
}

VARIABLE hart_software_minor_revision        /* U8 */
{
    LABEL "Minor";
    HELP "HART software minor rev.";
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (1)
    {
        DISPLAY_FORMAT "2d"; 
    }
}
           
/*******************************************************************************************/

//IMAGE mpc5 {PATH "mpc5_schema.gif";}

/********************************************************************************************************************
                    COMMON PRACTICE COMMANDS
*********************************************************************************************************************/
/**********************************************************************************************/


/********************************************************************************************************************
                    SERVICE COMMANDS
*********************************************************************************************************************/
/**********************************************************************************************/
COMMAND write_control_modes
{
	NUMBER 132;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			local_keys_mode_control_codes, 	/* U8,  0 = enabled. 1 = disabled */
			meter_information_configuration, 	/* U8, 0 = not_installed, 1 = integral_LCD */
			meter_display_mode, 			/* U8, 0=unit_on, 1=unit_off */
			meter_display_electronics_bias_control,	/* U8, not used */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>,  
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
							/*{BIT1,BIT0=00,     [LCD1  current]},
							{BIT1,BIT0=01,     [LCD1  percent_of_range]},

							{BIT3,BIT2=00,     [LCD2  pressure]},
							{BIT3,BIT2=01,     [LCD2  user_rerange]},*/

			meter_display_variable_decimal_point	/* U8
                            {1,     	[.XXXXX]},
							{2,     	[X.XXXX]},
							{3,     	[XX.XXX]},
							{4,     	[XXX.XX]},
							{5,     	[XXXX.X]},
							{6,     	[XXXXX.]}
							*/
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes,  	/* U8 */
			meter_information_configuration,	/* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point /* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		2,  DATA_ENTRY_ERROR,           [invalid_selection];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,				    [in_write_protect_mode];
	}
}

/**********************************************************************************************/

COMMAND read_control_modes
{
	NUMBER 133;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes, 	/* U8 */
			meter_information_configuration,   /* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable,  	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point	/* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

COMMAND read_static_data_material
{
	NUMBER 128;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{}
		REPLY
		{
			response_code, device_status,         /* U8 */ 
            process_connection_type, process_connection_material, o_ring_material,
            sensor_filling_fluid, nominal_measuring_range, static_pressure,
            diaphragm_seal_size, flange_type, seal_diaphragm_material,
            seal_contact_face_material, seal_filling_fluid, nominal_pressure,
            length_capillary_H, length_capillary_L, configuration_of_seal,
            cmd128_empty_byte

        }
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,				[no_command_specific_errors];
	}
}


/**********************************************************************************************/
COMMAND read_last_trim_points
{
	NUMBER 129;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{}
		REPLY
		{
            response_code,device_status,
			pressureUnits,          //T     /* U8 */
			sensor_lower_trim_point,//T     /* IEE754 float, jest to warto cinienia dla ostatnio wykonanej kalibracji */
			sensor_upper_trim_point,//T 	/* IEE754 float, jest to warto cinienia dla ostatnio wykonanej kalibracji */
			current_units, 		            /* U8 */
			current_lower_trim_point,	    /* IEE754 float, jest to warto {upper_trim_point} prdu dla ostatnio wykonanej kalibracji prdu */
			current_upper_trim_point	    /* IEE754 float, jest to warto {lower_trim_point}prdu dla ostatnio wykonanej kalibracji prdu */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,				[no_command_specific_errors];
	}
}


/**********************************************************************************************/
COMMAND write_upper_sensor_trim
/* Uwaga!, wejcie w procedur kalibracji zeruje podkalibrowanie zera */
{
    NUMBER 130;
    OPERATION WRITE;
    TRANSACTION
	{
		REQUEST
		{
			channel_number,       //T         /* U8, channel_number = 0 or 1  MPC5 */
			pressureUnits (INFO), 		    //T	        /* U8 */
			sensor_upper_trim_point //T		    /* IEE754 float */
		}
		REPLY
		{
			response_code,device_status,    	/* U8 */
			channel_number,			            /* U8 */
			pressureUnits,			            /* U8 */
			sensor_upper_trim_point 		    /* IEE754 float */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                	[no_command_specific_errors];
		2,      DATA_ENTRY_ERROR,       	[invalid_selection];
		3,      DATA_ENTRY_ERROR,      		[passed_parameter_too_large];
		4,      DATA_ENTRY_ERROR,      		[passed_parameter_too_small];
		5,      MISC_ERROR,             	[too_few_data_bytes_recieved];
		7,      MODE_ERROR,            		[in_write_protect_mode];
		11,     MISC_ERROR,             	[excess_correction];
		12,     DATA_ENTRY_ERROR,			"[invalid_unit_code]";
		14,     DATA_ENTRY_ERROR,       	[span_too_small];
	}
}



/**********************************************************************************************/
COMMAND write_lower_sensor_trim
/* Uwaga!, wejcie w procedur kalibracji zeruje podkalibrowanie zera */
{
    NUMBER 131;
    OPERATION WRITE;
    TRANSACTION
    {
		REQUEST
		{
			channel_number,       //T 	      /* U8,  channel_number = 0 lub 1 dla MPC5 */
			pressureUnits (INFO),	        //T		      /* U8 */
			sensor_lower_trim_point	//T	          /* IEE754 float */
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			channel_number,			        /* U8 */
			pressureUnits,			            /* U8 */
			sensor_lower_trim_point		        /* IEE754 float */
		}
    }
	RESPONSE_CODES
    {
		0,      SUCCESS,                		[no_command_specific_errors];
		2,      DATA_ENTRY_ERROR,      		    [invalid_selection];
		3,      DATA_ENTRY_ERROR,       		[passed_parameter_too_large];
		4,      DATA_ENTRY_ERROR,       		[passed_parameter_too_small];
		5,      MISC_ERROR,             		[too_few_data_bytes_recieved];
		7,      MODE_ERROR,             		[in_write_protect_mode];
		12,     DATA_ENTRY_ERROR,			    "[invalid_unit_code]";                       
		13,     MISC_ERROR,            			"[excess_correction_factors_out_of_limits]";
		14,     DATA_ENTRY_ERROR,      		    [span_too_small];
    }
}

/**********************************************************************************************/
COMMAND write_polynomial_coefficients_all
{
	NUMBER 135;
	OPERATION WRITE;
	TRANSACTION 0
	{
		REQUEST
		{       
			x0,y0,x1,y1,x2,y2,0
		}
		REPLY
		{
			response_code,device_status, 
			x0,y0,x1,y1,x2,y2,0
		}
    }
    TRANSACTION 1
	{
		REQUEST
		{       
			x3,y3,x4,y4,x5,y5,1
		}
		REPLY
		{
			response_code,device_status, 
			x3,y3,x4,y4,x5,y5,1
		}
    }
	TRANSACTION 2
	{
		REQUEST
		{       
			x6,y6,x7,y7,x8,y8,2
		}
		REPLY
		{
			response_code,device_status, 
			x6,y6,x7,y7,x8,y8,2
		}
    }
    TRANSACTION 3
	{
		REQUEST
		{       
			x9,y9,x10,y10,x11,y11,3
		}
		REPLY
		{
			response_code,device_status, 
			x9,y9,x10,y10,x11,y11,3
		}
    }
    TRANSACTION 4
	{
		REQUEST
		{       
			x12,y12,x13,y13,x14,y14,4
		}
		REPLY
		{
			response_code,device_status, 
			x12,y12,x13,y13,x14,y14,4
		}
    }
	TRANSACTION 5
	{
		REQUEST
		{       
			x15,y15,x16,y16,x17,y17,5
		}
		REPLY
		{
			response_code,device_status, 
			x15,y15,x16,y16,x17,y17,5
		}
    }
    TRANSACTION 6
	{
		REQUEST
		{       
			x18,y18,x19,y19,x20,y20,6
		}
		REPLY
		{
			response_code,device_status, 
			x18,y18,x19,y19,x20,y20,6
		}
    }

	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 [in_write_protect_mode];   
	}	
}


COMMAND read_polynomial_coefficients_all
{
	NUMBER 136;
	OPERATION READ;
	TRANSACTION 0
	{
		REQUEST
        {
        0
        }
        REPLY
		{
			response_code,device_status,
			x0,y0,x1,y1,x2,y2
		}
    }
	TRANSACTION 1
	{
		REQUEST
        {
        1
        }
        REPLY
		{
			response_code,device_status,
			x3,y3,x4,y4,x5,y5
		}
    }
	TRANSACTION 2
	{
		REQUEST
        {
        2
        }
        REPLY
		{
			response_code,device_status,
			x6,y6,x7,y7,x8,y8
		}
    }
	TRANSACTION 3
	{
		REQUEST
        {
        3
        }
        REPLY
		{
			response_code,device_status,
			x9,y9,x10,y10,x11,y11
		}
    }
	TRANSACTION 4
	{
		REQUEST
        {
        4
        }
        REPLY
		{
			response_code,device_status,
			x12,y12,x13,y13,x14,y14
		}
    }
	TRANSACTION 5
	{
		REQUEST
        {
        5
        }
        REPLY
		{
			response_code,device_status,
			x15,y15,x16,y16,x17,y17
		}
    }
	TRANSACTION 6
	{
		REQUEST
        {
        6
        }
        REPLY
		{
			response_code,device_status,
			x18,y18,x19,y19,x20,y20
		}
    }

	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
	}
}

/**********************************************************************************************/
COMMAND reset_factory_trim
{
	NUMBER 138;             
    
	OPERATION WRITE;

	TRANSACTION
	{
		REQUEST
		{
		kind_of_trim			/* U8,
                                    0 = undo zero trim,
                                    1 = sensor trim recall to factory settings,
                                    2 = analog output trim recall to factory settings 
                                */
		}
		REPLY
		{
		response_code, device_status,		/* U8 */
		kind_of_trim			            /* U8 */
		}
	}
    RESPONSE_CODES
	{
		0,  SUCCESS,                    		[no_command_specific_errors];
		2,  DATA_ENTRY_ERROR,           	    [invalid_selection];
		5,  MISC_ERROR,                 		[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 		[in_write_protect_mode];
	}
}

METHOD  reset_factory_trim_method
{
    LABEL "Trim";
    HELP  "Trim";
    DEFINITION 
    {  
    ACKNOWLEDGE("Press OK to Factory Trim");
    send_command(138);       
    }

}

/**********************************************************************************************/
COMMAND write_analog_input_function_block_configuration
{
	NUMBER 141;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
		    cmd141_byte0,			/* U8 */
		    cmd141_byte1,			/* U8 */
		    cmd141_byte2,			/* U8 */
            current_range_mode <0x80>,
            current_alarm    <0x40>,
            cmd141_empty_bit        <0x20>,
            DS33_state       <0x10>,
            oscillator_state <0x08>,
            EEPROM_state     <0x04>,
            ADC7794_state    <0x02>,
            hart_modem_state <0x01>
            
		    /*current_alarm_mode U8 */
						            /*
						            {BIT0 = 1  alarm od braku gotowoci modemu HART}
						            {BIT1 = 1  alarm od bdw ADC7794, mostka, referencji,napicia AVDD,bariery}
                                    {BIT2 = 1 alarm od bdw pamici RAM, EEPROM,PROGRAM}
						            {BIT3 = 1  alarm od bdu lokalnego oscylatora kwarcowego 32768Hz}
						            {BIT4 = 1  alarm od bdu statusu DS33= NOT-OK}
						            {BIT5        n.a}
						            {BIT6 = 0  prd alarmowy HIGH (22 mA)}
						            {BIT6 = 1  prd alarmowy LOW  (3,6 mA)}
						            {BIT7= 0  mod zakresu prdowego, NORMAL (3,920,5 mA)}
                                    {BIT7= 1  mod zakresu prdowego, NAMUR (3,8  20,5 mA)}
                                    {0x01},
                                    
                                    
						            */
		}

		REPLY
		{
			response_code,device_status 	/* U8 */
			cmd141_byte0,			/* U8 */
			cmd141_byte1,			/* U8 */
			cmd141_byte2,			/* U8 */
			/*current_alarm_mode   U8 */
            current_range_mode <0x80>,
            current_alarm    <0x40>,
            cmd141_empty_bit        <0x20>,
            DS33_state       <0x10>,
            oscillator_state <0x08>,
            EEPROM_state     <0x04>,
            ADC7794_state    <0x02>,
            hart_modem_state <0x01>

		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 [in_write_protect_mode];   
	}
}

/**********************************************************************************************/
COMMAND read_analog_input_function_block_configuration
{
	NUMBER 142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{       
		}
		REPLY
		{
			response_code, device_status, 	/* U8 */
			cmd141_byte0,			/* U8 */
			cmd141_byte1,			/* U8 */
			cmd141_byte2,			/* U8 */
			/*current_alarm_mode	 U8 */
            current_range_mode <0x80>,
            current_alarm    <0x40>,
            cmd141_empty_bit        <0x20>,
            DS33_state       <0x10>,
            oscillator_state <0x08>,
            EEPROM_state     <0x04>,
            ADC7794_state    <0x02>,
            hart_modem_state <0x01>

		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
	}
}

/**********************************************************************************************/
COMMAND read_revisions_code
{
    NUMBER 230;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			cpu_hardware_major_revision,    	/* U8 */
			cpu_hardware_minor_revision,        /* U8 */
			cpu_software_major_revision,       /* U8 */
			cpu_software_minor_revision,       /* U8 */
			master_software_major_revision,     /* U8 */
			master_software_minor_revision,     /* U8 */
			slave_software_major_revision,      /* U8 */
			slave_software_minor_revision,      /* U8 */
			adc_hardware_major_revision,        /* U8 */
			adc_hardware_minor_revision,        /* U8 */
			hart_software_major_revision,       /* U8 */
			hart_software_minor_revision        /* U8 */
         }
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}


/**********************************************************************************************/
/**********************************************************************************************/
COMMAND read_product_code
{
    NUMBER 231;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			product_code                        /* ASCII 16 */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}


/**********************************************************************************************/
COMMAND read_separator_code
{
    NUMBER 233;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			separator_code                 		/* ASCII 16 */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}

/**********************************************************************************************/
COMMAND read_manifold_code
{
    NUMBER 235;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			manifold_code                       /* ASCII 16 */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}


/**********************************************************************************************/
COMMAND read_operational_limits
{
    NUMBER 237;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status		/* U8 */
            eep_max_work_press_uc,      		/* U8, max_work_press_unit_code */
			eep_max_work_press,	            	/* max_work_pressure, IEE754 float */
            eep_min_work_press_uc,      		/*  U8, min_work_press_unit_code */
			eep_min_work_press,	            	/*  min_work_pressure, IEE754 float */
			eep_min_temp_unit_code,     		/* U8, min_temp_unit_code, zawsze [C] ! */
			eep_min_temp_value,	            	/* min_temp_value, IEE754 float */
			eep_max_temp_unit_code,	        	/* U8, min_temp_unit_code, zawsze [C] ! */
			eep_max_temp_value		        /* min_temp_value, IEE754 float */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}



/**********************************************************************************************/
COMMAND write_long_tag
{
	NUMBER 240;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			long_tag				/* ASCII 24 */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			long_tag				            /* ASCII 24 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    		[no_command_specific_errors];
		5,  MISC_ERROR,                			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 		[in_write_protect_mode];   
	}
}



/**********************************************************************************************/
COMMAND read_long_tag
{
    NUMBER 241;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status,		/* U8 */
			long_tag    			            /* ASCII 24 */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                	[no_command_specific_errors];
	}
}

/**********************************************************************************************/
COMMAND write_startpoint_rad
{
	NUMBER 242;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			startpoint_rad  			/* IEE754 float, warto w % zakresu */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			startpoint_rad          			/* IEE754 float, warto w % zakresu */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
		5,  MISC_ERROR,                 			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 			[in_write_protect_mode];   
	}
}



/**********************************************************************************************/
COMMAND read_startpoint_rad
{
    NUMBER 243;
    OPERATION READ;
    TRANSACTION
	{
		REQUEST
		{
		
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			startpoint_rad          			/* IEE754 float, warto w % zakresu */
		}
	}
    RESPONSE_CODES
	{
		0,      SUCCESS,                			[no_command_specific_errors];
	}
}



/**********************************************************************************************/
COMMAND write_users_unit_name_and_rearrange_coefficients
{
	NUMBER 244;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			users_unit,     			/* string w formacie ASCII(7) */
			rearrange_shift,			/* IEE754 float, jest to przeskalowanie LRV wywietlane na LCD w trybie user_rearrange.*/
			rearrange_ampl  			/* IEE754 float, jest to przeskalowanie URV wywietlane na LCD w trybie user_rearrange. */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,        			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
		5,  MISC_ERROR,                 			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 			[in_write_protect_mode];   
	}
}
/**********************************************************************************************/
COMMAND read_users_unit_name_and_rerange_coefficients
{
	NUMBER 245;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{       

		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,         			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

/********************************************************************************
;		sub_CMD_246	 CHANGE CUSTOMER SECURITY CODE		(8 bajtw danych)
;********************************************************************************
;                   byte 0-3 - old customer security code                       
;                   byte 3-7 - new customer security code
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Umoliwia zmian kodu zabezpieczajcego                          ;
;------------------------------------------------------------------------------*/

COMMAND CMD_246
{
    NUMBER 246;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           old_customer_code, new_customer_code
        }
        REPLY
        {
            response_code, device_status, old_customer_code, new_customer_code 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}     
   
/*******************************************************************************;
;		sub_CMD_247	SET WRITE PROTECT CODE	(5 bajtw danych)                   ;
;*******************************************************************************;
;                   byte 0-3 - customer security code                           ;
;                   byte 4 - write protect code                                 ;
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Po wpisaniu odpowiedniego kodu ustawiany jest write protect code ;
;------------------------------------------------------------------------------*/
 
COMMAND CMD_247
{
    NUMBER 247;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           protect_code, write_protect 
        }
        REPLY
        {
            response_code, device_status, protect_code, write_protect 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      2,  DATA_ENTRY_ERROR, [invalid_selection];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}  

/********************************************************************************************************************
 * Relationships
 ********************************************************************************************************************/

UNIT pressureUnitsRelation
{
    pressureUnits:
        pressureValue,
        pressureUSL,
        pressureLSL,
        pressureMinimumSpan     
}

UNIT eep_min_work_pressUnitsRelation
{
    eep_min_work_press_uc:
        eep_min_work_press       
}

UNIT eep_max_work_pressUnitsRelation
{
    eep_max_work_press_uc:
        eep_max_work_press       
}


/************************************************************
            Wykres '1' zmiennej procesowej PV
*************************************************************/
CHART pvChart
{
    LABEL [pv];                             // etykieta
    TYPE STRIP;                             
    HEIGHT MEDIUM;                          
    WIDTH MEDIUM;                           // jedna kolumna
    MEMBERS
    {
        pvSrc, pvSource;
    }
}

SOURCE pvSource                             // zmienne wywietlane                                   
{
    LABEL [pv];
    EMPHASIS TRUE;
    MEMBERS                                 // lista zmiennych
    {
        pvVar, PV.DEVICE_VARIABLE.DIGITAL_VALUE;
    }
}

/********************************************************
           Wykres procent zakresu 
********************************************************/

AXIS porAxis
{
    LABEL [pv_percent_range];
    MIN_VALUE 0;
    MAX_VALUE 110;
}

CHART percentOfRangeChart
{
    LABEL [pv_percent_range];
    TYPE HORIZONTAL_BAR;
    WIDTH XX_SMALL;
    HEIGHT XX_SMALL;
    MEMBERS
    {
        porSrc, porSource;
    }
}

SOURCE porSource
{
    Y_AXIS porAxis;
    LABEL [pv_percent_range];
    MEMBERS
    {
        porVar, PV.RANGING.PERCENT_RANGE;
    }
}

/*****************************************************
            Wykres Prdu
******************************************************/  

SOURCE currentSource
{
    LABEL [current];
    Y_AXIS currentAxis;
    MEMBERS
    {
        currentSrc, PV.DAQ.ANALOG_VALUE;
    }
}

AXIS currentAxis
{
    MIN_VALUE 3;
    MAX_VALUE 22;
}

CHART chart_current
{
    LABEL "Current chart";
    TYPE STRIP;
    WIDTH MEDIUM;
    HEIGHT MEDIUM;
    MEMBERS
    {
        curs, currentSource;
    }
}

/******************************************************
        Wykres SV1
 ******************************************************/ 

CHART svChart
{
    LABEL [sv];                             // etykieta
    TYPE STRIP;                             
    HEIGHT MEDIUM;                          
    WIDTH MEDIUM;                         // jedna kolumna
    MEMBERS
    {
        svSrc, svSource;
    }
}

SOURCE svSource                             // zmienne wywietlane                                   
{
    LABEL [sv];
    EMPHASIS TRUE;
    MEMBERS                                 // lista zmiennych
    {
        svVar, SV.DEVICE_VARIABLE.DIGITAL_VALUE;
  
    }
}  

/*******************************************************
        QV temperature
 *******************************************************/

CHART qvChart
{
    LABEL [qv];                             // etykieta
    TYPE STRIP;                             
    HEIGHT MEDIUM;                          
    WIDTH MEDIUM;                         // jedna kolumna
    MEMBERS
    {
        qvSrc, qvSource;
    }
}

SOURCE qvSource                             // zmienne wywietlane                                   
{
    LABEL [qv];
    EMPHASIS TRUE;
    MEMBERS                                 // lista zmiennych
    {
        qvVar, QV.DEVICE_VARIABLE.DIGITAL_VALUE;
  
    }
} 

/******************************************************
        Wykres TV
 ******************************************************/
 
CHART tvChart
{
    LABEL [tv];                             // etykieta
    TYPE STRIP;                             
    HEIGHT MEDIUM;                          
    WIDTH MEDIUM;                         // jedna kolumna
    MEMBERS
    {
        tvSrc, tvSource;
    }
}

SOURCE tvSource                             // zmienne wywietlane                                   
{
   // Y_AXIS sv1Axis;
    LABEL [tv];
    EMPHASIS TRUE;
    MEMBERS                                 // lista zmiennych
    {
        tvVar, TV.DEVICE_VARIABLE.DIGITAL_VALUE;
  
    }
}  

//************** koniec wywietlania ******************



/****************************************************************************
                MENU 
******************************************************************************/

MENU root_menu
{
    STYLE WINDOW; 
    LABEL [bus_devices];
    ITEMS
    {   
        //gorna zakladka
        //aplisensLogo (INLINE),
        //"                                       Aplisens Ltd.",
        //"                                     7 Morelowa Street\n                                       03-192 Warsaw"
        //SEPARATOR,
        //MPC5_logo (INLINE),
        //"               APC-2000ALW  -  HART CONFIGURATOR DDL",


       //glwne zakladki menu 

        menu_sensor_block,
        menu_transducer_block,
        menu_analog_input_output_block,
        menu_physical_block,
        menu_diagnostic,
        menu_lcd,
        menu_all_revisions
    }
}
//----------------------------------------------------------------------------
//              analog input & output block
//----------------------------------------------------------------------------
MENU menu_analog_input_output_block
{
    LABEL "Analog Input/Output";
    ITEMS 
    {  
        analog_input,
        analog_output,
        current_alarms,
        ROWBREAK,
        linearization_tab
    }
}

//---------------------------------------------------------------------------
//          Sensor block
//---------------------------------------------------------------------------
MENU menu_sensor_block
{
    LABEL [pressure_sensor];
    ITEMS 
    {  
        signal_conditioning,
        temperature_sensor,
        ADC_Temperatute//,
        //[blank],
        //mpc5
    }
}
//---------------------------------------------------------------------------
//              Physical block
//---------------------------------------------------------------------------
MENU menu_physical_block
{
    LABEL "Physical Block";
    ITEMS 
    {  
        device_identification,
        device_info,
        device_revisions,
        hart_output,
        return_to_factory_settings,
        reset_device_flag_menu,
        write_security,
        sep_mat_code,
        temp_operational_limits,
        CPU_temperature,
        menu_device_flags,
        menu_static_data_material
    }
}
//--------------------------------------------------------------------------
//          Transducer block
//--------------------------------------------------------------------------
MENU menu_transducer_block
{
    LABEL "Transducer Block";
    ITEMS 
    {  
        last_trim_points,
        process_variables
        //channel_number (DISPLAY_VALUE, READ_ONLY)//_frame
    }
}


MENU last_trim_points
{
    LABEL "Last trim points";
    ITEMS 
    {  
        sensor_upper_trim_point (DISPLAY_VALUE, READ_ONLY),
        sensor_lower_trim_point (DISPLAY_VALUE, READ_ONLY),
        sensor_a_lower_sensor_trim,
        sensor_a_upper_sensor_trim,
        m_set_pv_zero//,
        //[blank]
    }
}

METHOD m_set_pv_zero
{
    LABEL "Set PV zero";
    HELP  "Pressure of the process measured with respect to a reference pressure.";
    CLASS CORRECTION;
    DEFINITION 
    {  
        ACKNOWLEDGE("Press OK to Set PV Zero");
        send_command(43);
    }
}

//-------------------------------------------------------------------------
//           Diagnostic
//-------------------------------------------------------------------------
MENU menu_diagnostic
{
    LABEL [diagnostics_and_service];
    ITEMS 
    {  
        commands_status,
        extended_status,
        AI_Memory_Diagn,
        PB_Memory_Diagn,
        TB_Memory_Diagn,
        SB_Memory_Diagn,
        analog_channel_saturated,
        analog_channel_fixed,
        device_specific_status
    }
}
//-------------------------------------------------------------------------
//                  LCD
//-------------------------------------------------------------------------
MENU menu_lcd
{
    LABEL "LCD";
    ITEMS 
    {  
        menu_local_LCD,
        menu_user_unit,
        //users_unit (DISPLAY_VALUE),
        menu_user_rarange
        //rearrange_shift (DISPLAY_VALUE),
        //rearrange_ampl (DISPLAY_VALUE)
    }
}

MENU menu_local_LCD
{
    LABEL "Local LCD";
    ITEMS 
    {  
        local_keys_mode_control_codes (DISPLAY_VALUE),
        meter_information_configuration (DISPLAY_VALUE),       
        LCD2_display_variable (DISPLAY_VALUE),
        LCD1_display_variable (DISPLAY_VALUE),
        meter_display_variable_decimal_point (DISPLAY_VALUE)//,
        //[blank]

    }
}

MENU menu_user_unit
{
    LABEL "User Unit";
    HELP "Display Unit - Unit that is displayed on the LCD Display";
    ITEMS 
    {  
    users_unit (DISPLAY_VALUE)//,
    //[blank]
    }
}

MENU menu_user_rarange
{
    LABEL "User Rerange";
    HELP "User Rerange";
    ITEMS 
    {  
    //[blank],
    rearrange_shift (DISPLAY_VALUE),
    rearrange_ampl (DISPLAY_VALUE)//,
    //[blank]
    }
}

/*******************************************************************************
********************************************************************************/

//wykresy zmienych procesowych i procentu zakresu
MENU display_chart      //charts_percent_of_range
{
    STYLE DIALOG;
    LABEL "variables and percent of range charts";
    ITEMS
    {
       chart_menu_cur,
       chart_menu_pv,
       chart_menu_sv,
       chart_menu_tv,
       chart_menu_qv,
       chart_menu_por
    }
}

MENU chart_menu_cur
{
    STYLE DIALOG;
    LABEL "Current chart";
    ITEMS 
    {  
       chart_current
    }
}

MENU chart_menu_pv
{
    STYLE DIALOG;
    LABEL "PV Chart";
    ITEMS 
    {  
     pvChart
    }
}

MENU chart_menu_sv
{
    STYLE DIALOG;
    LABEL "SV Chart";
    ITEMS 
    {  
     svChart
    }
}

MENU chart_menu_tv
{
    STYLE DIALOG;
    LABEL "TV Chart";
    ITEMS 
    {  
       tvChart
    }
}

MENU chart_menu_qv
{
    STYLE DIALOG;
    LABEL "QV Chart";
    ITEMS 
    {  
        qvChart
    }
}

MENU  chart_menu_por
{
   STYLE DIALOG;
   LABEL "Percent of range";
   ITEMS
   {
       percentOfRangeChart 
   }
}

MENU process_variables
{
    LABEL [process_variables];
    ITEMS
    {
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),       // variable
        PV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE),
        PV.RANGING.PERCENT_RANGE (DISPLAY_VALUE),               // variable 
        PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),         // variable 
        display_chart//,
        //[blank]
    }
}  
  
MENU communication_status
{
    LABEL "Communication status";
    HELP "Field Device Status: Data indicating that the Field Device has detected condition(s) "
         "in the Field Device relating to: its hardware / the validity of a variable / its "
         "operating status / an internal process.";
    ITEMS
    { 
    //response_code (DISPLAY_VALUE),
    [blank]
    }
}   

MENU commands_status
{
    LABEL "Commands status";
    ITEMS
    {
    device_status //(DISPLAY_VALUE)
    }
} 

MENU extended_status
{
    LABEL "Device Specific Status (Byte 2, 3)";
    HELP "Device Specific Status (Byte 2, 3)";
    ITEMS
    {
    wrd_SSMod_H_2,
    SEPARATOR,
    device_specific_status_3
    }
} 


MENU AI_Memory_Diagn
{
    LABEL "Analog Input Memory Diagnostics";
    HELP "Analog Input Memory Diagnostics";
    ITEMS
    {
    device_specific_status_14//,
    //[blank]
    }
}

MENU PB_Memory_Diagn
{
    LABEL "Physical Block Memory Diagnostics";
    HELP "Physical Block Memory Diagnostics";
    ITEMS
    {
    device_specific_status_15,
    //[blank],
    SEPARATOR,
    device_specific_status_19
    }
}

MENU SB_Memory_Diagn
{
    LABEL "Sensor Block Memory Diagnostics";
    HELP "Sensor Block Memory Diagnostics";
    ITEMS
    {
    device_specific_status_16,
    SEPARATOR,
    device_specific_status_21,
    device_specific_status_20
    }
}

MENU TB_Memory_Diagn
{
    LABEL "Transducer Block Memory Diagnostics";
    HELP "Transducer Block Memory Diagnostics";
    ITEMS
    {
    device_specific_status_17//,
    //[blank],[blank],[blank],[blank]
    }
}

MENU device_specific_status
{
    LABEL "Device Specific Status";
    HELP "Device Specific Status";
    ITEMS
    {
    device_specific_status_0,
    device_specific_status_1,
    SEPARATOR, 
    device_specific_status_4,
    device_specific_status_5
    }
}

MENU analog_channel_saturated
{
    LABEL "Analog Channel Saturated";
    ITEMS
    {
    //analog_channel_saturated3,
    //SEPARATOR,
    //analog_channel_saturated2,
    //SEPARATOR,
    analog_channel_saturated1
    }
}

MENU analog_channel_fixed
{
    LABEL "Analog Channel Fixed";
    ITEMS
    {
    //analog_channel_fixed3,
    //SEPARATOR,
    //analog_channel_fixed2, 
    //SEPARATOR,
    analog_channel_fixed1
    }
}
                     
                        
MENU test_device 
{
    LABEL [test_device];
    ITEMS
    {
        device_self_test,       // method 
        device_master_reset     // method 
    }
} 

MENU menu_all_revisions
{
    LABEL "Revisions";
    ITEMS
    {
        device_revisions, 
        ADC_revision,
        CPU_hardware_revision,
        CPU_software_revision,       // variable
        Master_software_revision,
        Slave_software_revision,
        Hart_software_revision
    }
}
        
MENU device_revisions
{
    LABEL "Device revision";
    ITEMS
    {
        universal_revision (DISPLAY_VALUE),     // variable 
        transmitter_revision (DISPLAY_VALUE),   // variable 
        hardware_revision  (DISPLAY_VALUE),
        software_revision (DISPLAY_VALUE)       // variable
    }
}

MENU ADC_revision
{
    LABEL "ADC hardware revision";
    ITEMS 
    {  
        adc_hardware_major_revision (DISPLAY_VALUE),
        adc_hardware_minor_revision (DISPLAY_VALUE)
    }
}

MENU CPU_hardware_revision
{
    LABEL "CPU hardware revision";
    ITEMS 
    {  
        cpu_hardware_major_revision (DISPLAY_VALUE), //cpu_hardware_rev, 
        cpu_hardware_minor_revision (DISPLAY_VALUE)
    }
}

MENU CPU_software_revision
{
    LABEL "CPU software revision";
    ITEMS 
    {  
        cpu_software_major_revision (DISPLAY_VALUE), //cpu_software_rev,
        cpu_software_minor_revision (DISPLAY_VALUE)        
    }
}

MENU Master_software_revision
{
    LABEL "Master software revision";
    ITEMS 
    {  
        master_software_major_revision (DISPLAY_VALUE), //master_software_rev,
        master_software_minor_revision (DISPLAY_VALUE)        
    }
}

MENU Slave_software_revision
{
    LABEL "Slave software revision";
    ITEMS 
    {  
        slave_software_major_revision (DISPLAY_VALUE), //slave_software_rev,
        slave_software_minor_revision (DISPLAY_VALUE)               
    }
}

MENU Hart_software_revision
{
    LABEL "Hart software revision";
    ITEMS 
    {  
        hart_software_major_revision (DISPLAY_VALUE),
        hart_software_minor_revision (DISPLAY_VALUE)                  
    }
}

MENU CPU_temperature
{
    LABEL "CPU Temperature";
    ITEMS 
    {  
        TV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
        TV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE)//,
        //[blank]
    }
}

MENU menu_device_flags
{
    LABEL "Device Flags";
    ITEMS 
    {  
        device_flags (DISPLAY_VALUE)
    }
}

MENU menu_static_data_material
{
    LABEL "Static Data Materials";
    ITEMS 
    {  

       process_connection_type(DISPLAY_VALUE), 
       process_connection_material(DISPLAY_VALUE), 
       o_ring_material(DISPLAY_VALUE),
       sensor_filling_fluid(DISPLAY_VALUE), 
       nominal_measuring_range(DISPLAY_VALUE), 
       static_pressure(DISPLAY_VALUE),
       diaphragm_seal_size(DISPLAY_VALUE), 
       flange_type(DISPLAY_VALUE), 
       SEPARATOR,
       seal_diaphragm_material(DISPLAY_VALUE),
       seal_contact_face_material(DISPLAY_VALUE), 
       seal_filling_fluid(DISPLAY_VALUE), 
       nominal_pressure(DISPLAY_VALUE),
       length_capillary_H(DISPLAY_VALUE), 
       length_capillary_L(DISPLAY_VALUE),
       configuration_of_seal(DISPLAY_VALUE)

/*
        flange_type (DISPLAY_VALUE),
        flange_material (DISPLAY_VALUE),
        o_ring_material (DISPLAY_VALUE),
        drain_vent_material (DISPLAY_VALUE), //odpowietrznik
        remote_seal_type (DISPLAY_VALUE),
        siepres_remote_seal_fill_fluid (DISPLAY_VALUE),
        SEPARATOR,
        remote_seal_isolator_material (DISPLAY_VALUE),
        number_of_remote_seals (DISPLAY_VALUE),
        module_fill_fluid (DISPLAY_VALUE),
        module_isolator_material (DISPLAY_VALUE),
        module_type_code (DISPLAY_VALUE),
        module_range_code (DISPLAY_VALUE)
*/        
    }
}

MENU device_identification
{
    LABEL "Device identification";
    ITEMS
    {
        manufacturer_id (DISPLAY_VALUE),
        device_type (DISPLAY_VALUE),                /* variable */
        device_id (DISPLAY_VALUE),                  /* variable */
        private_label_distributor (DISPLAY_VALUE),  /* variable */ 
        final_assembly_number (DISPLAY_VALUE,READ_ONLY)       /* variable */   
    }
}

MENU device_info
{
    LABEL [device_information];
    ITEMS
    {
        tag (DISPLAY_VALUE),
        long_tag (DISPLAY_VALUE),
        descriptor (DISPLAY_VALUE),                 
        message (DISPLAY_VALUE),
        date (DISPLAY_VALUE)        
    }
}

MENU sep_mat_code
{
    LABEL "Separator and material code";
    ITEMS
    {
        //[blank],
        product_code (DISPLAY_VALUE),
        separator_code (DISPLAY_VALUE),
        manifold_code (DISPLAY_VALUE)// ,
        //[blank]
    }
}


MENU temp_operational_limits
{
    LABEL "Temp operational limits";
    ITEMS
    {       
		eep_min_temp_value (DISPLAY_VALUE),	            	/* min_temp_value, IEE754 float */
        //eep_min_temp_unit_code,     		/* U8, min_temp_unit_code, zawsze [C] ! */
        //[blank],
		eep_max_temp_value (DISPLAY_VALUE)		        /* min_temp_value, IEE754 float */
        //eep_max_temp_unit_code//,	        	/* U8, min_temp_unit_code, zawsze [C] ! */
        //[blank]
    }
}


MENU write_security
{
    LABEL "Write protection";
    ITEMS 
    {  
       write_protect (DISPLAY_VALUE, READ_ONLY),
       toggle_write_protect,
       //protect_code,
       //set_protect,
       change_protect_code//,
       //[blank]
    }
} 

METHOD toggle_write_protect
{
    LABEL "Set Write Protect";
    HELP  "";
    DEFINITION 
    {
     assign_int(protect_code,0000);
     GET_DEV_VAR_VALUE( "Type Protect Code", protect_code);
     GET_DEV_VAR_VALUE( "Set Write Protect", write_protect);
     send_command(247);
     //assign_int(protect_code,0000);
    }
}
METHOD change_protect_code
{
    LABEL "Change Protect Code";
    HELP  "";
    DEFINITION 
    {
     assign_int(old_customer_code,0000);
     assign_int(new_customer_code,0000);
     GET_DEV_VAR_VALUE( "Type Old Customer Code", old_customer_code);
     GET_DEV_VAR_VALUE( "Type new Customer Code", new_customer_code);
     //assign_int(old_customer_code,0000);
     //assign_int(new_customer_code,0000);
    }
}

MENU signal_conditioning
{
    LABEL [signal_condition];
    ITEMS
    {
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
        //PV.DEVICE_VARIABLE.DIGITAL_UNITS (READ_ONLY),
        //SEPARATOR,
        PV.DEVICE_VARIABLE.UPPER_SENSOR_LIMIT (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.LOWER_SENSOR_LIMIT (DISPLAY_VALUE),
        //SEPARATOR,
        PV.DEVICE_VARIABLE.MINIMUM_SPAN (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DAMPING_VALUE (DISPLAY_VALUE),
        //SEPARATOR,
        eep_min_work_press (DISPLAY_VALUE),	            	/*  min_work_pressure, IEE754 float */
        //eep_min_work_press_uc,      		/*  U8, min_work_press_unit_code */
        //SEPARATOR,
        eep_max_work_press (DISPLAY_VALUE),	            	/* max_work_pressure, IEE754 float */
        //eep_max_work_press_uc,      		/* U8, max_work_press_unit_code */
        //SEPARATOR,
        PV.DEVICE_VARIABLE.SENSOR_SERIAL_NUMBER (DISPLAY_VALUE)
    }
}


MENU temperature_sensor
{
    LABEL "Sensor Temperature";
    ITEMS
    {       
       SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
       SV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE)

    }
}

MENU ADC_Temperatute
{
    LABEL "ADC Temperatute";
    ITEMS
    {       
       QV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),
       QV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE)

    }
}

//-------------------------------------------------------------------------------
//              analog input//output
//-------------------------------------------------------------------------------
MENU analog_input
{
    LABEL "Analog input";
    ITEMS 
    {  
        PV.RANGING.PERCENT_RANGE (DISPLAY_VALUE),
        PV.RANGING.TRANSFER_FUNCTION (DISPLAY_VALUE),        //redefine
        
        //nieczulosc
        startpoint_rad (DISPLAY_VALUE),
        PV.RANGING.LOWER_RANGE_VALUE (DISPLAY_VALUE),       // variable 
        PV.RANGING.UPPER_RANGE_VALUE (DISPLAY_VALUE),       // variable
        
        menu_span,
        menu_zero
    }
}

//przycisk SPAN
METHOD menu_span
{
     LABEL "SPAN";
     DEFINITION
    {  
         ACKNOWLEDGE("Press OK to Set Span");
         send_command(36);
    }
} 

//przycisk ZERO
METHOD menu_zero
{
    LABEL "ZERO";
    DEFINITION
    {  
        ACKNOWLEDGE("Press OK to Set Zero");
        send_command(37);      
    }
}

MENU analog_output
{
        LABEL [analog_output];
        ITEMS
        {
            PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE,READ_ONLY),  // variable 
            current_alarm (DISPLAY_VALUE),
            current_range_mode (DISPLAY_VALUE),
            user_loop_test,
            transmitter_dac_trim
        }
} 

MENU current_alarms
{
        LABEL "Current Alarms";
        ITEMS
        {   //[blank],
            hart_modem_state (DISPLAY_VALUE),
            ADC7794_state (DISPLAY_VALUE),
            EEPROM_state (DISPLAY_VALUE),
            oscillator_state (DISPLAY_VALUE),
            DS33_state (DISPLAY_VALUE)//,
            //[blank]
        }
} 

METHOD leave_fixed_current_mode
{
	LABEL [leaving_fixed_current_mode];
	HELP [leaving_fixed_current_mode_help_2];

	DEFINITION
	{
		char status[STATUS_SIZE];
		long var_id[1];
		char disp_string1[60];
		int slen1;

		slen1 =60;

		assign_float(PV.DAQ.ANALOG_VALUE,0.0);
		IGNORE_ALL_RESPONSE_CODES();
		do
		{
			get_dictionary_string(return_fld_dev_to_orig_otpt,disp_string1,slen1);
			DELAY(3,disp_string1);
			send(40,status);
			if ( status[   0] )
			{
				display_response_status(40,status[   0]);
			}
		}
		while ( status[   0]);
		get_dictionary_string(loop_may_be_returned_to_auto,disp_string1,slen1);
		ACKNOWLEDGE(disp_string1);
	}
}


METHOD user_loop_test
{
    LABEL [loop_test];
    HELP [loop_test_help];
    DEFINITION
    {
        char status[STATUS_SIZE];
        char disp_string1[60];
        char disp_string2[60];
        long var_id[1];
        int use_abort_method;
        int choice;
        int slen1;
        int slen2;

        slen1 = 60;
        slen2 = 60;

        IGNORE_ALL_RESPONSE_CODES();
        IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_RESPONSE_CODES();

        get_dictionary_string(remove_loop_from_auto, disp_string1, slen1);
        ACKNOWLEDGE(disp_string1);
        add_abort_method(return_to_normal);

        /* 
         * Here comes the standard part for analog outputs, e.g. transmitters 
         */
        use_abort_method = 0;

        do 
        {
            get_dictionary_string(choose_analog_output_level, disp_string1, slen1);
            get_dictionary_string(choices_4_20_other_end, disp_string2, slen2);

            choice = SELECT_FROM_LIST(disp_string1, disp_string2);

            switch (choice)
            {
            case 0:
                assign_float(PV.DAQ.ANALOG_VALUE,4.0);
                break;

            case 1:
                assign_float(PV.DAQ.ANALOG_VALUE,20.0);
                break;

            case 2:
                get_dictionary_string(loop_output, disp_string1, slen1);
                GET_DEV_VAR_VALUE(disp_string1, PV.DAQ.ANALOG_VALUE);
                break;

            case 3:
            default:
                process_abort();
                break;
            }

            send(40, status);

            if (!use_abort_method)
            {
                if ((status[STATUS_RESPONSE_CODE] != 0)
                        && ( status[STATUS_RESPONSE_CODE] != 3)
                        && ( status[STATUS_RESPONSE_CODE] != 4))
                {
                    display_response_status(40,status[STATUS_RESPONSE_CODE]);
                    get_dictionary_string(abort_last_error, disp_string1, slen1);
                    DELAY(2, disp_string1);
                    process_abort();
                }

                if (status[STATUS_RESPONSE_CODE] == 0)
                {
                    remove_abort_method(return_to_normal);
                    add_abort_method(leave_fixed_current_mode);
                    use_abort_method =1;
                }
            }

            if (status[STATUS_RESPONSE_CODE])
            {
                /* 
                 * Display the resonse code from the error 
                 */
                display_response_status(40, status[STATUS_RESPONSE_CODE]);

                /* 
                 * If the response code is either 3 or 4, meaning the value
                 * was either too large or too small, do not abort method.
                 * Allow the user to try again. 
                 */ 
                if ((status[STATUS_RESPONSE_CODE] != 3)
                        && ( status[STATUS_RESPONSE_CODE] != 4))
                {
                    get_dictionary_string(abort_last_error, disp_string1, slen1);
                    DELAY(2, disp_string1);
                    process_abort();
                }
            }
            else
            {
                var_id[0] = VARID(PV.DAQ.ANALOG_VALUE);
                get_dictionary_string(fld_dev_otpt_fixed, disp_string1, slen1);
                acknowledge(disp_string1, var_id);
            }
            } while (choice < 3);
        //ACKNOWLEDGE("Press OK to exit Fixed Current Mode");
        //PV.DAQ.ANALOG_VALUE = 0;
        //send_command(40);
        process_abort();
    }
}


/****************************************************************************** */
//     Methods Press Common_Prac                                                                                                   */
/****************************************************************************** */

METHOD sensor_a_lower_sensor_trim
{
	LABEL   "Set Lower Sensor Trim";
    HELP    "Pressure Sensor Lower Trim: Calibrate the pressure sensor.";
    DEFINITION
	{
		long ids[1];
		char status[STATUS_SIZE];
		float trim_point;
		int rc;
		char disp_string1[60];
		char disp_string2[60];
		int slen1;
		int slen2;
        int wybor;
		slen1=60;
		slen2=60;
        
		get_dictionary_string(remove_loop_from_auto,disp_string1,slen1);
		wybor = ACKNOWLEDGE(disp_string1);
		add_abort_method(return_to_normal);
                                                                            
		get_dictionary_string(this_will_affect_snsr_cal,disp_string1,slen1);
		ACKNOWLEDGE(disp_string1);

		add_abort_method(leave_trim_mode);
        do
		{
            GET_DEV_VAR_VALUE( "Set the channel number", channel_number);
            ACKNOWLEDGE("Apply low pressure");
            ids[0] = VARID(PV.DEVICE_VARIABLE.DIGITAL_VALUE);

            GET_DEV_VAR_VALUE( "What is the pressure ?", PV.DEVICE_VARIABLE.DIGITAL_VALUE);
            ACKNOWLEDGE("Pressure is stable");

			trim_point = fvar_value(PV.DEVICE_VARIABLE.DIGITAL_VALUE);
			rc=GET_LOCAL_VAR_VALUE("Enter applied pressure value", trim_point);

			fassign(sensor_lower_trim_point,trim_point);
			send(131,status);    // Send the lower_sensor_trim value. 

			if ( status[STATUS_RESPONSE_CODE] )
			{
				display_response_status(131,status[STATUS_RESPONSE_CODE]);
			}
		}
		while ( status[STATUS_RESPONSE_CODE] );
        
		DELAY(2,"Remove_pressure");
    }
}

METHOD sensor_a_upper_sensor_trim
{
	LABEL   "Set Upper Sensor Trim";
	HELP    "Pressure Sensor Upper Trim: Calibrate the pressure sensor.";

    DEFINITION
    {
		long ids[1];
		char status[STATUS_SIZE];
		float trim_point;
		int rc;
		char disp_string1[60];
		char disp_string2[60];
		int slen1;
		int slen2;

		slen1=60;
		slen2=60;

		get_dictionary_string(remove_loop_from_auto,disp_string1,slen1);
		ACKNOWLEDGE(disp_string1);
		add_abort_method(return_to_normal);

		get_dictionary_string(this_will_affect_snsr_cal,disp_string1,slen1);
		ACKNOWLEDGE(disp_string1);
		add_abort_method(leave_trim_mode);
		do
		{
            GET_DEV_VAR_VALUE( "Set the channel number", channel_number);
			ACKNOWLEDGE("Apply hi press");
			ids[0] = VARID(PV.DEVICE_VARIABLE.DIGITAL_VALUE);
			ACKNOWLEDGE("Pressure is stable");
			trim_point = fvar_value(PV.DEVICE_VARIABLE.DIGITAL_VALUE);
			rc=GET_LOCAL_VAR_VALUE("Enter applied pressure value", trim_point);
			fassign(sensor_upper_trim_point,trim_point);
			send(130,status);
			if ( status[STATUS_RESPONSE_CODE] )
			{
				display_response_status(130,status[STATUS_RESPONSE_CODE]);
			}
		}
		while ( status[STATUS_RESPONSE_CODE] );
		DELAY(2,"Remove pressure");
    }
}

METHOD leave_trim_mode
{
	LABEL           "Leave trim mode";
    HELP            "Leave trim mode";
    DEFINITION
    {
		ACKNOWLEDGE("Trim was not done");
    }
}


MENU hart_output
{
        LABEL [HART_output];
        ITEMS
        {
            polling_address (DISPLAY_VALUE),        // variable 
            request_preambles (DISPLAY_VALUE),      // variable
            response_preambles (DISPLAY_VALUE)
        }       
}
/*
METHOD method_response_preambles
{
    LABEL "Response Preambles";
    HELP  "";
    DEFINITION 
    {
    int var;
    int rc;
    char status[STATUS_SIZE];

    var = ivar_value(request_preambles);
	rc=GET_LOCAL_VAR_VALUE("Set Response Preambles", var);
	iassign(response_preambles,var);
    iassign(request_preambles,var);
    //send_command(59);

			send(59,status);
			if ( status[STATUS_RESPONSE_CODE] )
			{
				display_response_status(130,status[STATUS_RESPONSE_CODE]);
			}
    //save_values();
    }
} 
*/


MENU return_to_factory_settings
{
    LABEL "Return to Factory Settings";
    ITEMS 
    {  
        kind_of_trim,
        //reset_factory_trim_method,
        reset_device         
    } 
}

MENU reset_device_flag_menu
{
    LABEL "Reset Device Flag";
    ITEMS 
    {  

        reset_device_flag//,
        //reset_device
        //[blank]
         
    } 
}
METHOD reset_device_flag
{
    LABEL "Reset Configuration Changed Flag";
    HELP  "";
    DEFINITION 
    {  
        ACKNOWLEDGE("Press OK to Reset Configuration Changed Flag");
        send_command(38);
    }
}

METHOD reset_device
{
    LABEL "Reset Device";
    HELP  "Reset Device?";
    DEFINITION 
    {  
        ACKNOWLEDGE("Press OK to Reset Device");
        send_command(42);
    }
}

MENU linearization_tab
{
   // STYLE DIALOG;
	LABEL           "Linearization Table";
	ITEMS
	{
			    x0(DISPLAY_VALUE),
                y0(DISPLAY_VALUE),
                x1(DISPLAY_VALUE),
                y1(DISPLAY_VALUE),
                x2(DISPLAY_VALUE),
                y2(DISPLAY_VALUE),
                x3(DISPLAY_VALUE),
                y3(DISPLAY_VALUE),
                x4(DISPLAY_VALUE),
                y4(DISPLAY_VALUE),
                x5(DISPLAY_VALUE),
                y5(DISPLAY_VALUE),
                x6(DISPLAY_VALUE),
                y6(DISPLAY_VALUE),
                x7(DISPLAY_VALUE),
                y7(DISPLAY_VALUE),
                x8(DISPLAY_VALUE),
                y8(DISPLAY_VALUE),
                x9(DISPLAY_VALUE),
                y9(DISPLAY_VALUE),
              SEPARATOR,
                x10(DISPLAY_VALUE),
                y10(DISPLAY_VALUE),
                x11(DISPLAY_VALUE),
                y11(DISPLAY_VALUE),
                x12(DISPLAY_VALUE),
                y12(DISPLAY_VALUE),
                x13(DISPLAY_VALUE),
                y13(DISPLAY_VALUE),
                x14(DISPLAY_VALUE),
                y14(DISPLAY_VALUE),
                x15(DISPLAY_VALUE),
                y15(DISPLAY_VALUE),
                x16(DISPLAY_VALUE),
                y16(DISPLAY_VALUE),
                x17(DISPLAY_VALUE),
                y17(DISPLAY_VALUE),
                x18(DISPLAY_VALUE),
                y18(DISPLAY_VALUE),
                x19(DISPLAY_VALUE),
                y19(DISPLAY_VALUE),
                x20(DISPLAY_VALUE),
                y20(DISPLAY_VALUE)
	}
}

//----------------------------------------------------------------------

